@@ -64,7 +64,7 @@ Coff::AuxSymbol *Coff::AuxSymbol::factory(const Object &object, AuxSymbolType ty
     case AuxSymbolType::Section:    return new AuxSymbolSection(object, data, offset, stringTableOffset, log);
     case AuxSymbolType::Nb_Types:   return new AuxSymbolUnknown(object);
   }
-  Q_ASSERT(false);
+  ASSERT(false);
   return 0;
 }
 
@@ -213,7 +213,7 @@ Coff::Symbol::Symbol(const Object &object, const QByteArray &data, uint start,
   else if ( _sclass==SymbolClass::Filename ) auxType = AuxSymbolType::File;
   else if ( _sclass==SymbolClass::Section ) auxType = AuxSymbolType::Section;
   if ( auxType!=AuxSymbolType::Nb_Types && nbAux==0 ) log.log(Log::LineType::Warning, i18n("Symbol without needed auxilliary symbol (type=%1)").arg(auxType.type()));
-  Q_ASSERT( (offset-start)==object.size(SymbolSize) );
+  ASSERT( (offset-start)==object.size(SymbolSize) );
   _aux.resize(nbAux);
   for (uint i=0; i<nbAux; i++) {
     _aux[i] = AuxSymbol::factory(object, auxType, data, offset, stringTableOffset, log);
@@ -360,7 +360,7 @@ Coff::Section::Section(const Device::Data &device, const Object &object,
   _flags = v;
 
   // read data
-  Q_ASSERT ( device.group().name()=="pic" );
+  ASSERT ( device.group().name()=="pic" );
   const Pic::Data &pdata = static_cast<const Pic::Data &>(device);
   log.log(Log::DebugLevel::Max, QString("section \"%1\": address=%2 size=%3 flags=%4").arg(_name).arg(toHexLabel(_address, 2*4)).arg(_size).arg(_flags));
   if ( _size!=0 && dataOffset!=0 ) {
@@ -458,7 +458,7 @@ bool Coff::Object::parse(Log::Base &log)
   if ( !parseHeader(data, offset, log) ) return false;
 
   // optionnal header
-  Q_ASSERT( offset==size(HeaderSize) );
+  ASSERT( offset==size(HeaderSize) );
   if ( !getULong(data, offset, 2, log, _optHeaderMagic) ) return false;
   log.log(Log::DebugLevel::Extra, QString("COFF optionnal header format: %1").arg(toHexLabel(_optHeaderMagic, 4)));
   _optHeaderFormat = OptHeaderFormat::Nb_Types;
@@ -492,7 +492,7 @@ bool Coff::Object::parse(Log::Base &log)
   }
 
   // parse sections
-  Q_ASSERT( offset==(size(HeaderSize) + size(OptHeaderSize)) );
+  ASSERT( offset==(size(HeaderSize) + size(OptHeaderSize)) );
   _sections.resize(_nbSections);
   for (uint i=0; i<_nbSections; i++) {
     _sections[i] = new Section(*_device, *this, data, offset, stringTableOffset, log);
@@ -624,7 +624,8 @@ QValueVector<Pic::RegisterNameData> Pic::sfrList(const Pic::Data &data)
     Register::TypeData td(it.key(), it.data().address, it.data().nbChars);
     list.append(Pic::RegisterNameData(it.key(), td));
   }
-  if ( data.architecture()==Pic::Architecture::P16X )
+  if ( data.architecture()==Pic::Architecture::MidRange
+       || data.architecture()==Pic::Architecture::EMidRange)
     list.append(Pic::RegisterNameData("WREG", Register::TypeData("WREG", rdata.nbChars())));
   qSort(list);
   return list;
@@ -648,9 +649,8 @@ Pic::RegisterNameData Pic::gprNameData(const Pic::RegistersData &rdata, uint ind
 QValueVector<Pic::RegisterNameData> Pic::variableList(const Pic::RegistersData &rdata, const Coff::Object &coff)
 {
   QValueVector<Pic::RegisterNameData> list;
-  QMap<QString, Address> variables = coff.variables();
-  QMap<QString, Address>::const_iterator vit;
-  for (vit=variables.begin(); vit!=variables.end(); ++vit) {
+  const QMap<QString, Address>& variables = coff.variables();
+  for (QMap<QString, Address>::const_iterator vit=variables.begin(); vit!=variables.end(); ++vit) {
     Register::TypeData rtd(vit.data(), rdata.nbChars());
     list.append(Pic::RegisterNameData(vit.key() + " (" + toHexLabel(vit.data(), rdata.nbCharsAddress()) + ")", rtd));
   }
