@@ -68,6 +68,9 @@ struct px pics[] = {
   { PROC_CLASS_PIC14,   "__12F683",   { "pic12f683",   "p12f683",   "12f683"   }, 0xf683, 1, 2, 0x21ff,   { 0x800, 0x20ff },     { 0x2007, 0x2007 },     "12f683.lkr"   },
   { PROC_CLASS_PIC14,   "__14000",    { "pic14000",    "p14000",    "14000"    }, 0x4000, 2, 2, 0xfbf,    { -1, -1 },            { 0x2007, 0x2007 },     "14000.lkr"    },
   { PROC_CLASS_PIC14,   "__16CXX",    { "pic16cxx",    "p16cxx",    "16cxx"    }, 0x6c77, 4, 4, -1,       { -1, -1 },            { -1, -1 },             NULL           },
+  { PROC_CLASS_PIC14,   "__16F1826",  { "pic16f1826",  "p16f1826",  "16f1826"  }, 0x1826, 1, 0x1f, 0xf0ff,{ 0x1000, 0xefff },    { 0x8007, 0x8008 },     "16f1826.lkr"  },
+  { PROC_CLASS_PIC14,   "__16F1827",  { "pic16f1827",  "p16f1827",  "16f1827"  }, 0x1827, 2, 0x1f, 0xf0ff,{ 0x1000, 0xefff },    { 0x8007, 0x8008 },     "16f1827.lkr"  },
+  { PROC_CLASS_PIC14,   "__16F1829",  { "pic16f1829",  "p16f1829",  "16f1829"  }, 0x1829, 4, 0x20, 0xf0ff,{ 0x2000, 0xefff },    { 0x8007, 0x8008 },     "16f1829.lkr"  },
   { PROC_CLASS_PIC14,   "__16F1933",  { "pic16f1933",  "p16f1933",  "16f1933"  }, 0x1933, 2, 2, 0xf0ff,   { 0x1000, 0xefff },    { 0x8007, 0x8008 },     "16f1933.lkr"  },
   { PROC_CLASS_PIC14,   "__16LF1933", { "pic16lf1933", "p16lf1933", "16lf1933" }, 0xa933, 2, 2, 0xf0ff,   { 0x1000, 0xefff },    { 0x8007, 0x8008 },     "16lf1933.lkr" },
   { PROC_CLASS_PIC14,   "__16F1934",  { "pic16f1934",  "p16f1934",  "16f1934"  }, 0x1934, 2, 2, 0xf0ff,   { 0x1000, 0xefff },    { 0x8007, 0x8008 },     "16f1934.lkr"  },
