@@ -42,6 +42,7 @@ const CLI::CommandData STANDARD_COMMAND_DATA[] = {
 const CLI::CommandData STANDARD_INTERACTIVE_COMMAND_DATA[] = {
   { "help",          CLI::ListCommand,       0, 0, I18N_NOOP("Display help.") },
   { "exit",          CLI::NoCommandProperty, 0, 0, I18N_NOOP("Exit.") },
+  { "quit",          CLI::NoCommandProperty, 0, 0, I18N_NOOP("Exit.") },
   { "set",           CLI::NoCommandProperty, 1, 2, I18N_NOOP("Set property value: \"set <property> <value>\" or \"<property> <value>\".") },
   { "unset",         CLI::NoCommandProperty, 1, 1, I18N_NOOP("Unset property value: \"unset <property>\".") },
   { "get",           CLI::NoCommandProperty, 1, 1, I18N_NOOP("Get property value: \"get <property>\" or \"<property>\".") },
@@ -515,7 +516,7 @@ CLI::ExitCode CLI::MainBase::prepareProcessLine(QStringList& words)
 
 CLI::ExitCode CLI::MainBase::processStandardLine(const QStringList& words)
 {
-  if (words[0] == "exit") return EXITING;
+  if (words[0] == "exit" || words[0] == "quit") return EXITING;
   if (words[0] == "set") {
     if (words.count() == 2) return executeSetCommand(words[1], QString::null, false);
     return executeSetCommand(words[1], words[2], false);
