@@ -9,10 +9,8 @@
 #include "synchronous.h"
 #include "synchronous.moc"
 
+#include "common/common/misc.h"
 #include "global.h"
-#if QT_VERSION<0x040000
-#  include <qwidget.h>
-#endif
 
 //------------------------------------------------------------------------------
 Synchronous::Synchronous(uint timeout)
@@ -24,46 +22,22 @@ Synchronous::Synchronous(uint timeout)
     connect(_timer, SIGNAL(timeout()), SLOT(done()));
     _timer->start(timeout, true);
   }
-#if QT_VERSION>=0x040000
   _loop = new QEventLoop(this);
-#endif
 }
 
-#if QT_VERSION<0x040000
-void qt_enter_modal(QWidget *widget);
-void qt_leave_modal(QWidget *widget);
-#endif
-
 bool Synchronous::enterLoop()
 {
-  Q_ASSERT( _state!=Running );
+  ASSERT( _state!=Running );
   if ( _state==Done ) return true;
   _state = Running;
-#if QT_VERSION<0x040000
-  std::auto_ptr<QWidget> dummy;
-  if ( qApp->type()!=QApplication::Tty ) {
-    dummy.reset(new QWidget(0, 0, WType_Dialog | WShowModal));
-    dummy->setFocusPolicy(QWidget::NoFocus);
-    qt_enter_modal(dummy.get());
-  }
-  QApplication::eventLoop()->enterLoop();
-  if ( qApp->type()!=QApplication::Tty ) {
-    qt_leave_modal(dummy.get());
-  }
-#else
   _loop->exec();
-#endif
   return (_timer != NULL ? _timer->isActive() : true);
 }
 
 void Synchronous::done()
 {
   if ( _state==Running ) {
-#if QT_VERSION<0x040000
-    QApplication::eventLoop()->exitLoop();
-#else
     _loop->exit();
-#endif
   }
   _state = Done;
 }
