@@ -31,10 +31,10 @@ public:
   QStringList readListEntry(const QString &key, const QStringList &defaultValues) const;
   void writeEntry(const QString &key, const QStringList &value);
 
-  QValueList<int> readIntListEntry(const QString &key) const;
-  void writeEntry(const QString &key, const QValueList<int> &value);
+  QList<int> readIntListEntry(const QString &key) const;
+  void writeEntry(const QString &key, const QList<int> &value);
 
-  QSize readSizeEntry(const QString &key, const QSize *def = 0) const;
+  QSize readSizeEntry(const QString &key, QSize def = QSize()) const;
   void writeEntry(const QString &key, const QSize &value);
 
   bool readBoolEntry(const QString &key, bool def) const;
@@ -59,7 +59,9 @@ public:
     QVariant defValue;
   };
   template <typename Type>
-  QVariant readVariantEntry(Type type) const { return readVariantEntry(type.key(), type.data().defValue); }
+  QVariant readVariantEntry(Type type) const {
+    return readVariantEntry(type.key(), type.data().defValue);
+  }
   template <typename Type>
   void writeVariantEntry(Type type, const QVariant &value) {
     ASSERT( value.type()==type.data().defValue.type() );
