@@ -23,7 +23,8 @@ Process::Base::Base(QObject *parent, const char *name)
     _stopExecute(false)
 {
   _process = new ProcessIO(this);
-  connect(_process, SIGNAL(processExited()), SLOT(exitedSlot()));
+  connect(_process, SIGNAL(finished()), SLOT(finishedSlot()));
+  connect(_process, SIGNAL(error()), SLOT(errorSlot()));
   connect(_process, SIGNAL(readyReadStdout()), SLOT(readyReadStdoutSlot()));
   connect(_process, SIGNAL(readyReadStderr()), SLOT(readyReadStderrSlot()));
   connect(&_timer, SIGNAL(timeout()), SLOT(timeoutSlot()));
@@ -51,7 +52,7 @@ void Process::Base::clearOutputs()
   FOR_EACH(OutputType, type) _outputs[type] = QString::null;
 }
 
-bool Process::Base::start(int msec)
+void Process::Base::start(int msec)
 {
   _state = Stopped;
   clearOutputs();
@@ -68,14 +69,9 @@ bool Process::Base::start(int msec)
     env += _environment;
   }
 
-  if ( !_process->start(env.isEmpty() ? 0 : &env) ) {
-    _state = StartFailed;
-    return false;
-  }
-
+  _process->start(env.isEmpty() ? 0 : &env);
   if (msec >=0 ) _timer.start(msec);
   _state = Running;
-  return true;
 }
 
 int Process::Base::exitCode() const
@@ -83,12 +79,19 @@ int Process::Base::exitCode() const
   return _process->_kproc->exitCode();
 }
 
-void Process::Base::exitedSlot()
+void Process::Base::finishedSlot()
 {
   _timer.stop();
   _state = Exited;
   FOR_EACH(OutputType, type) readyRead(type);
-  emit done(exitCode());
+  emit done();
+}
+
+void Process::Base::errorSlot()
+{
+  _timer.stop();
+  _state = Error;
+  emit error();
 }
 
 void Process::Base::timeoutSlot()
@@ -165,9 +168,7 @@ void Process::Base::readyRead(OutputType type)
 
 bool Process::Base::execute(int msec)
 {
-  if (_state != Running && !start()) {
-    return false;
-  }
+  if (_state != Running) start();
 
   while (msec != 0) {
     int step = 100;
