@@ -27,7 +27,7 @@ namespace Process
 //typedef Q3Process ProcessIO;
 
 //----------------------------------------------------------------------------
-enum State { Stopped, StartFailed, Running, Exited, Timedout, Killed };
+enum State { Stopped, Error, Running, Exited, Timedout, Killed, };
 
 BEGIN_DECLARE_ENUM(OutputType)
   Stdout = 0, Stderr
@@ -45,7 +45,7 @@ public:
   QString prettyCommand() const { return arguments().join(" "); }
   void setWorkingDirectory(const PURL::Directory &dir);
   void setUseShell(bool useShell);
-  virtual bool start(int msec = -1); // -1 == no timeout
+  void start(int msec = -1); // -1 == no timeout
   void writeToStdin(const QString &s);
   bool signal(int n);
   bool isRunning() const;
@@ -55,7 +55,8 @@ public:
   bool execute(int msec); // -1 == no timeout
 
 signals:
-  void done(int code);
+  void done();
+  void error();
   void timeout();
   void dataReceived(::Process::OutputType type);
 
@@ -63,7 +64,8 @@ public slots:
   void kill();
 
 protected slots:
-  void exitedSlot();
+  void finishedSlot();
+  void errorSlot();
   void timeoutSlot();
   void readyReadStdoutSlot() { readyRead(OutputType::Stdout); }
   void readyReadStderrSlot() { readyRead(OutputType::Stderr); }
