@@ -17,7 +17,8 @@ Process::ProcessIO::ProcessIO(QObject *parent)
   _kproc->setOutputChannelMode(KProcess::SeparateChannels);
   connect(_kproc.get(), SIGNAL(readyReadStandardOutput()), SLOT(receivedStandardOutput()));
   connect(_kproc.get(), SIGNAL(readyReadStandardError()), SLOT(receivedStandardError()));
-  connect(_kproc.get(), SIGNAL(stateChanged(QProcess::ProcessState)), SLOT(stateChanged(QProcess::ProcessState)));
+  connect(_kproc.get(), SIGNAL(error(QProcess::ProcessError)), SIGNAL(error()));
+  connect(_kproc.get(), SIGNAL(finished(int, QProcess::ExitStatus)), SIGNAL(finished()));
 }
 
 void Process::ProcessIO::setArguments(const QStringList &args)
@@ -30,7 +31,7 @@ void Process::ProcessIO::setArguments(const QStringList &args)
   }
 }
 
-bool Process::ProcessIO::start(QStringList *env)
+void Process::ProcessIO::start(QStringList *env)
 {
   if (env) {
     for (QStringList::const_iterator it = env->begin();
@@ -42,7 +43,6 @@ bool Process::ProcessIO::start(QStringList *env)
   }
   _kproc->setOutputChannelMode(KProcess::SeparateChannels);
   _kproc->start();
-  return true;
 }
 
 QByteArray Process::ProcessIO::readStdout()
@@ -78,8 +78,3 @@ void Process::ProcessIO::receivedStandardError()
   for (int i=0; i<data.size(); i++) _stderr[n+i] = data[i] != '\0' ? data[i] : ' ';
   emit readyReadStderr();
 }
-
-void Process::ProcessIO::stateChanged(QProcess::ProcessState state)
-{
-  if (state == QProcess::NotRunning) emit processExited();
-}
