@@ -21,19 +21,19 @@ Q_OBJECT
 public:
   ProcessIO(QObject *parent = 0);
   void setArguments(const QStringList &args);
-  bool start(QStringList *env = 0);
+  void start(QStringList *env = 0);
   QByteArray readStdout();
   QByteArray readStderr();
 
 private slots:
   void receivedStandardOutput();
   void receivedStandardError();
-  void stateChanged(QProcess::ProcessState);
 
 signals:
   void readyReadStdout();
   void readyReadStderr();
-  void processExited();
+  void error();
+  void finished();
 
 private:
   std::auto_ptr<KProcess> _kproc;
