@@ -14,24 +14,77 @@
 #include <qdir.h>
 #include <qregexp.h>
 #include <qmap.h>
+#include <QtNetwork/QNetworkRequest>
+#include <QtNetwork/QNetworkReply>
 
 #include "common/common/synchronous.h"
 #include "process.h"
-
-#if !defined(NO_KDE)
-#  include <kio/netaccess.h>
-#  include <kfileitem.h>
-#  include <kconfig.h>
-#endif
-
 #include "pfile.h"
 
 //-----------------------------------------------------------------------------
-PURL::Http::Http(const QString &hostname)
-  : QHttp(hostname)
+PURL::NetAccess::NetAccess(QObject* parent)
+: QObject(parent)
 {
-  connect(this, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
-          SLOT(responseHeaderReceivedSlot(const QHttpResponseHeader &)));
+  _manager = new QNetworkAccessManager(this);
+  connect(_manager, SIGNAL(finished(QNetworkReply*)), SLOT(finished(QNetworkReply*)));
+}
+
+bool PURL::NetAccess::exists(const Base& purl)
+{
+  QEventLoop eventLoop;
+  connect(_manager, SIGNAL(finished(QNetworkReply*)), &eventLoop, SLOT(quit()));
+  QNetworkRequest req(purl.kurl());
+  _manager->get(req);
+  eventLoop.exec();
+  return _reply->error() != QNetworkReply::NoError;
+}
+
+bool PURL::NetAccess::download(const Base& purl, QByteArray& data, Log::Generic& log)
+{
+  QEventLoop eventLoop;
+  connect(_manager, SIGNAL(finished(QNetworkReply*)), &eventLoop, SLOT(quit()));
+  QNetworkRequest req(purl.kurl());
+  _manager->get(req);
+  eventLoop.exec();
+  if (_reply->error() != QNetworkReply::NoError) {
+    log.sorry(i18n("Download error %1").arg(_reply->error()), purl.pretty());
+    return false;
+  }
+  data = _reply->readAll();
+  return true;
+}
+
+bool PURL::NetAccess::upload(const Base& purl, const QByteArray& data, Log::Generic& log)
+{
+  QEventLoop eventLoop;
+  connect(_manager, SIGNAL(finished(QNetworkReply*)), &eventLoop, SLOT(quit()));
+  QNetworkRequest req(purl.kurl());
+  _manager->put(req, data);
+  eventLoop.exec();
+  if (_reply->error() != QNetworkReply::NoError) {
+    log.sorry(i18n("Upload error %1").arg(_reply->error()), purl.pretty());
+    return false;
+  }
+  return true;
+}
+
+bool PURL::NetAccess::del(const Base& purl, Log::Generic& log)
+{
+  QEventLoop eventLoop;
+  connect(_manager, SIGNAL(finished(QNetworkReply*)), &eventLoop, SLOT(quit()));
+  QNetworkRequest req(purl.kurl());
+  _manager->deleteResource(req);
+  eventLoop.exec();
+  if (_reply->error() != QNetworkReply::NoError) {
+    log.sorry(i18n("Delete error %1").arg(_reply->error()), purl.pretty());
+    return false;
+  }
+  return true;
+}
+
+void PURL::NetAccess::finished(QNetworkReply* reply)
+{
+  _reply.reset(reply);
 }
 
 //-----------------------------------------------------------------------------
@@ -249,45 +302,18 @@ bool PURL::Base::isInto(const Directory &dir) const
   return path().startsWith(dir.path());
 }
 
-bool PURL::Base::httpUrlExists(bool *ok) const
-{
-  if (ok) *ok = false;
-  Http http(_url.host());
-  Synchronous sync(500);
-  QObject::connect(&http, SIGNAL(done(bool)), &sync, SLOT(done()));
-  QFileInfo info(_url.fileName(KUrl::ObeyTrailingSlash));
-  http.head(_url.path());
-  if ( !sync.enterLoop() ) return false; // timeout
-  if ( http.error()!=QHttp::NoError ) return false;
-  if (ok ) *ok = true;
-  return ( http._header.statusCode()==200 );
-}
-
 bool PURL::Base::exists(QDateTime *lastModified) const
 {
-  if ( isEmpty() ) return false;
-  if ( isLocal() ) {
+  if (isEmpty()) return false;
+  if (isLocal()) {
     QFileInfo fi(_url.path());
     if (lastModified) *lastModified = fi.lastModified();
     return fi.exists();
   }
-  if ( _url.protocol()=="http" ) return httpUrlExists();
-#if !defined(NO_KDE)
-  if (lastModified) {
-    KIO::UDSEntry uds;
-    if ( !KIO::NetAccess::stat(_url, uds, qApp->mainWidget()) ) return false;
-    KFileItem item(uds, _url);
-    *lastModified = item.time(KFileItem::ModificationTime).dateTime();
-    return true;
-  } else {
-    // assume file exists if ioslave cannot tell...
-    return KIO::NetAccess::exists(_url, KIO::NetAccess::SourceSide, qApp->mainWidget());
-  }
-#else
-  if (lastModified) lastModified->setTime_t(0);
-  // assume file exists
-  return true;
-#endif
+
+  // ### TODO: lastModified
+  std::auto_ptr<NetAccess> access(new NetAccess);
+  return access->exists(_url);
 }
 
 //----------------------------------------------------------------------------
@@ -386,6 +412,50 @@ bool PURL::findExistingUrl(Url &url)
   return true;
 }
 
+bool PURL::Url::copyTo(const Url &destination, Log::Generic &log) const
+{
+  if (isLocal() && destination.isLocal()) {
+    bool ok = QFile::copy(filepath(), destination.filepath());
+    if (!ok) log.sorry(i18n("Could not copy file"), destination.pretty());
+    return ok;
+  }
+
+  std::auto_ptr<NetAccess> access(new NetAccess);
+  QByteArray data;
+  return access->download(*this, data, log) && access->upload(destination, data, log);
+}
+
+bool PURL::Url::create(Log::Generic &log) const
+{
+  if (isLocal()) {
+    // do not overwrite
+    QFile file(filepath());
+    if (file.exists()) {
+      return false;
+    }
+    bool ok = file.open(QIODevice::WriteOnly);
+    if (!ok) log.sorry(i18n("Could not create file"), pretty());
+    return ok;
+  }
+
+  std::auto_ptr<NetAccess> access(new NetAccess);
+  if (access->exists(*this)) return false;
+  QByteArray data;
+  return access->upload(*this, data, log);
+}
+
+bool PURL::Url::del(Log::Generic &log) const
+{
+  if (isLocal()) {
+    bool ok = QFile::remove(filepath());
+    if (!ok) log.sorry(i18n("Could not delete file"), pretty());
+    return ok;
+  }
+
+  std::auto_ptr<NetAccess> access(new NetAccess);
+  return access->del(*this, log);
+}
+
 //-----------------------------------------------------------------------------
 PURL::UrlList::UrlList(const KUrl::List &list)
 {
@@ -430,6 +500,19 @@ PURL::Url PURL::Directory::findMatchingFilename(const QString &filename) const
   return Url(*this, filename);
 }
 
+bool PURL::Directory::create(Log::Generic &log) const
+{
+  if (isLocal()) {
+    QDir root = QDir::root();
+    bool ok = root.mkpath(path());
+    if (!ok) log.sorry(i18n("Could not create directory"), pretty());
+    return ok;
+  }
+
+  log.sorry(i18n("Could not create non-local directory"), pretty());
+  return false;
+}
+
 //-----------------------------------------------------------------------------
 bool PURL::isRelative(const QString &filepath)
 {
