@@ -129,7 +129,7 @@ Process::State Process::runSynchronouslyDialog(Base &process, const QString& msg
 {
   Synchronous sync(1000);
   QObject::connect(&process, SIGNAL(done(int)), &sync, SLOT(done()));
-  if ( process.state()!=Running && !process.start() ) return process.state();
+  if (process.state()!=Running) process.start();
   if (sync.enterLoop()) return process.state();
 
   // continue running the process with a dialog
