@@ -17,20 +17,19 @@
 #ifdef NO_KDE
 #  include "common/nokde_gui/nokde_dialog.h"
 #else
-#  include <kdialogbase.h>
+#  include <kdialog.h>
+#  include <kpagedialog.h>
 #endif
 
 //-----------------------------------------------------------------------------
-class Dialog : public KDialogBase
+class Dialog : public KDialog
 {
 Q_OBJECT
 public:
-  Dialog(QWidget *parent, const char *name, bool modal,
-         const QString &caption, int buttonMask, ButtonCode defaultButton, bool separator,
-         const QSize &defaultSize = QSize());
-  Dialog(DialogType type, const QString &caption,
-         int buttonMask, ButtonCode defaultButton, QWidget *parent, const char *name,
-         bool modal, bool separator, const QSize &defaultSize = QSize());
+  Dialog(QWidget *parent, const char *name,
+	 bool modal, const QString &caption,
+	 ButtonCodes buttons, ButtonCode defaultButton,
+	 bool separator, const QSize &defaultSize = QSize());
   virtual ~Dialog();
 
   static int spacingHint();
@@ -42,37 +41,34 @@ private:
   QSize                       _defaultSize;
   std::auto_ptr<BusyCursorStarter> _busyCursor;
 };
-
 //-----------------------------------------------------------------------------
-class TreeListDialog : public Dialog
+class PageDialog : public KPageDialog
 {
 Q_OBJECT
 public:
-  TreeListDialog(QWidget *parent, const char *name, bool modal,
-                 const QString &caption, int buttonMask, ButtonCode defaultButton, bool separator);
-  QWidget *addPage(const QStringList &labels);
-  void showPage(QWidget *page);
-  int activePageIndex() const;
-  int pageIndex(QWidget *page) const;
+  PageDialog(QWidget *parent, const char *name,
+	     bool modal, const QString &caption,
+	     ButtonCodes buttons, ButtonCode defaultButton,
+	     bool separator, const QSize &defaultSize = QSize());
+  virtual ~PageDialog();
 
 private slots:
-  virtual void currentChanged(Q3ListViewItem *item);
-  void pageDestroyed(QObject *page);
+  void updateSize();
 
-protected:
-  QFrame        *_frame;
-  ListView      *_listView;
-  QHBoxLayout   *_titleBox;
-  QLabel        *_label;
-  Q3WidgetStack *_stack;
+private:
+  QSize                       _defaultSize;
+  std::auto_ptr<BusyCursorStarter> _busyCursor;
+};
 
- class Item : public KListViewItem {
-  public:
-    Item(const QString &label, QWidget *page, const QString &title, Q3ListView *listview);
-    Item(const QString &label, QWidget *page, const QString &title, Q3ListViewItem *item);
-    QWidget *_page;
-    QString  _title;
-  };
+//-----------------------------------------------------------------------------
+class TreeListDialog : public PageDialog
+{
+Q_OBJECT
+public:
+  TreeListDialog(QWidget *parent, const char *name,
+		 bool modal, const QString &caption,
+		 ButtonCodes buttons, ButtonCode defaultButton,
+		 bool separator);
 };
 
 //-----------------------------------------------------------------------------
@@ -98,7 +94,7 @@ public slots:
   void finished();
 };
 
-extern State runSynchronouslyDialog(Base &process, RunActions actions, const QString& msg);
+extern State runSynchronouslyDialog(Base &process, const QString& msg);
 
 } // namespace
 
