@@ -11,7 +11,7 @@
 
 //----------------------------------------------------------------------------
 PopupContainer::PopupContainer(const QString &title, QWidget *parent, const char *name)
-  : KPopupMenu(parent)
+  : KMenu(parent)
 {
   setObjectName(name);
   if ( !title.isEmpty() ) addTitle(title);
