@@ -23,7 +23,7 @@ public:
 };
 
 //----------------------------------------------------------------------------
-class PopupContainer : public KPopupMenu, public ListContainer
+class PopupContainer : public KMenu, public ListContainer
 {
 Q_OBJECT
 public:
