@@ -167,7 +167,7 @@ void PopupButton::init()
 {
   _separator = false;
   setFlat(true);
-  KPopupMenu *popup = new KPopupMenu(this);
+  KMenu *popup = new KMenu(this);
   connect(popup, SIGNAL(activated(int)), SIGNAL(activated(int)));
   setPopup(popup);
 }
