@@ -13,8 +13,8 @@
 #  include "common/nokde_gui/nokde_text_editor.h"
 #else
 #  include <kparts/part.h>
-#  include <kate/view.h>
-#  include <kate/document.h>
+#  include <ktexteditor/view.h>
+#  include <ktexteditor/document.h>
 #endif
 
 #endif
