@@ -11,21 +11,31 @@
 
 #include "port_base.h"
 
+#ifdef Q_OS_UNIX
+#  include <linux/hiddev.h>
+#endif
+
+
 namespace Port
 {
 
 class HID : public Base
 {
 public:
-  HID(Log::Base &base, uint vendorId, uint productId);
+  HID(Log::Base &base, uint vendorId, uint productId, uint size);
   virtual ~HID();
   virtual Description description() const { return Description(PortType::HID, QString::null); }
 
+  bool write(const char *data, uint size);
+  bool read(char *data, uint size);
+
   static QString devicePath(uint index);
   static bool getDeviceIds(uint index, uint& vendorId, uint& productId);
   static bool findDevice(uint vendorId, uint productId, uint& index);
   static bool isAvailable();
   static QStringList probedDeviceList();
+  static void listReports(int fd);
+  static void listReports(int fd, int type, const char* name);
 
 protected:
   virtual bool internalOpen();
@@ -37,6 +47,11 @@ private:
   uint _vendorId;
   uint _productId;
   int  _handle;
+
+  hiddev_report_info     _repInfoIn;
+  hiddev_report_info     _repInfoOut;
+  hiddev_usage_ref_multi _refMultiIn;
+  hiddev_usage_ref_multi _refMultiOut;
 };
 
 } // namespace
