@@ -19,7 +19,7 @@ struct PortTypeData {
 };
 
 BEGIN_DECLARE_ENUM(PortType)
-  Serial = 0, Parallel, USB
+  Serial = 0, Parallel, USB, HID
 END_DECLARE_ENUM(PortType, PortTypeData)
 
 namespace Port
