@@ -130,9 +130,9 @@ const Port::Serial::SPinData Port::Serial::PIN_DATA[Nb_Pins] = {
   { Out,  "RI"  }
 };
 
-std::vector<Port::PinData> Port::Serial::pinData(IODir dir) const
+QValueVector<Port::PinData> Port::Serial::pinData(IODir dir) const
 {
-  std::vector<PinData> v;
+  QValueVector<PinData> v;
   for (uint i=0; i<Nb_Pins; i++) {
     if ( PIN_DATA[i].dir!=dir ) continue;
     PinData pd = { i, PIN_DATA[i].label };
@@ -341,7 +341,7 @@ bool Port::Serial::internalSetPinOn(Pin pin, bool on)
     case DTR: bit = TIOCM_DTR; break;
     case RTS: bit = TIOCM_RTS; break;
     case RI:  bit = TIOCM_RI; break;
-    default:  Q_ASSERT(false); return false;
+    default:  ASSERT(false); return false;
   }
   return ( ioctl(_fd, on ? TIOCMBIS : TIOCMBIC, &bit)>=0 );
 #elif defined(Q_OS_WIN)
@@ -351,7 +351,7 @@ bool Port::Serial::internalSetPinOn(Pin pin, bool on)
     case DTR: func = (on ? SETDTR : CLRDTR); break;
     case RTS: func = (on ? SETRTS : CLRRTS); break;
     case RI:  // #### not possible with Win32 API ??
-    default:  Q_ASSERT(false); return false;
+    default:  ASSERT(false); return false;
   }
   return ( EscapeCommFunction(_fd, func)!=0 );
 #endif
@@ -361,8 +361,8 @@ bool Port::Serial::setPinOn(uint pin, bool on, LogicType type)
 {
   if ( _fd==INVALID_HANDLE ) return false;
   if ( type==NegativeLogic ) on = !on;
-  Q_ASSERT( pin<Nb_Pins );
-  Q_ASSERT( PIN_DATA[pin].dir==Out );
+  ASSERT( pin<Nb_Pins );
+  ASSERT( PIN_DATA[pin].dir==Out );
   if ( !internalSetPinOn(Pin(pin), on) ) {
     setSystemError(i18n("Error setting bit %1 of serial port to %2").arg(PIN_DATA[pin].label).arg(on));
     return false;
@@ -381,7 +381,7 @@ bool Port::Serial::internalReadPin(Pin pin, LogicType type, bool &value)
     case RX : mask = TIOCM_SR;  break;
     case DSR: mask = TIOCM_DSR; break;
     case CTS: mask = TIOCM_CTS; break;
-    default:  Q_ASSERT(false); return false;
+    default:  ASSERT(false); return false;
   }
   value = ((type==NegativeLogic ? ~bits : bits) & mask);
   return true;
@@ -393,7 +393,7 @@ bool Port::Serial::internalReadPin(Pin pin, LogicType type, bool &value)
     case DSR: value = (status & MS_DSR_ON); break;
     case CTS: value = (status & MS_CTS_ON); break;
     case RX:  // not possible with Win32 API ??
-    default:  Q_ASSERT(false); return false;
+    default:  ASSERT(false); return false;
   }
   if ( type==NegativeLogic) value = !value;
   return true;
@@ -403,8 +403,8 @@ bool Port::Serial::internalReadPin(Pin pin, LogicType type, bool &value)
   bool Port::Serial::readPin(uint pin, LogicType type, bool &value)
 {
   if ( _fd==INVALID_HANDLE ) return false;
-  Q_ASSERT( pin<Nb_Pins );
-  Q_ASSERT( PIN_DATA[pin].dir==In );
+  ASSERT( pin<Nb_Pins );
+  ASSERT( PIN_DATA[pin].dir==In );
   if ( !internalReadPin(Pin(pin), type, value) ) {
     setSystemError(i18n("Error reading serial pin %1").arg(PIN_DATA[pin].label));
     return false;
@@ -414,7 +414,7 @@ bool Port::Serial::internalReadPin(Pin pin, LogicType type, bool &value)
 
 bool Port::Serial::setMode(InputFlags inputFlags, ControlFlags controlFlags, Speed speed, uint readTimeout)
 {
-  Q_ASSERT (SPEED_DATA[speed].supported );
+  ASSERT (SPEED_DATA[speed].supported );
   if ( !flush(0) ) return false;
   Parameters parameters;
   if ( !getParameters(parameters) ) return false;
