@@ -17,7 +17,7 @@ Device::HexView::HexView(const HexEditor &editor, QWidget *parent, const char *n
 void Device::HexView::display(Memory *memory)
 {
   _memory = memory;
-  for (uint i=0; i<_editors.count(); i++) delete _editors[i];
+  for (int i=0; i<_editors.count(); i++) delete _editors[i];
   _editors.clear();
   if ( _memory==0 ) return;
   internalDisplay();
