@@ -49,11 +49,7 @@ void Device::MemoryRangeEditor::init()
   vbox->addStretch(1);
   QHBoxLayout *fbox = new QHBoxLayout(frame, 5, 5);
   Q3Grid *grid = new Q3Grid(3+_nbCols,
-#ifdef NO_KDE
                             Qt::Horizontal,
-#else
-                            Q3Grid::Horizontal,
-#endif
                             frame, "memory_range_editor_grid");
   fbox->addWidget(grid);
   grid->setSpacing(0);
@@ -86,11 +82,7 @@ void Device::MemoryRangeEditor::init()
 
   //  scrollbar if there are more lines to display than visible
   _scrollbar = new QScrollBar(0, QMAX(_nbLines, totalNbLines)-_nbLines, 1, _nbLines, 0,
-#ifdef NO_KDE
                               Qt::Vertical,
-#else
-                              QScrollBar::Vertical,
-#endif
                               frame, "memory_range_editor_scrollbar");
   connect(_scrollbar, SIGNAL(valueChanged(int)), SLOT(setIndex(int))) ;
   if ( totalNbLines<=_nbLines ) _scrollbar->hide();
@@ -124,7 +116,7 @@ void Device::MemoryRangeEditor::setComment(const QString &text)
 
 void Device::MemoryRangeEditor::setReadOnly(bool readOnly)
 {
-  for (uint i=0; i<_editors.count(); i++)
+  for (int i=0; i<_editors.count(); i++)
     _editors[i]->setReadOnly(readOnly || isRangeReadOnly());
 }
 
@@ -152,7 +144,7 @@ void Device::MemoryRangeEditor::setIndex(int index)
   _scrollbar->blockSignals(false);
 
   // memory
-  for (uint i=0; i<_editors.count(); i++) {
+  for (int i=0; i<_editors.count(); i++) {
     int offset = wordOffset() + i;
     _editors[i]->setOffset(offset<int(nbWords()) ? offset : -1);
   }
@@ -160,7 +152,7 @@ void Device::MemoryRangeEditor::setIndex(int index)
   // adresses
   uint inc = addressIncrement();
   Address address = startAddress() + inc * wordOffset();
-  for (uint i=0; i<_addresses.count(); i++) {
+  for (int i=0; i<_addresses.count(); i++) {
     _addresses[i]->setText(toHex(address, 2*_memory->device().nbBytesAddress()));
     updateAddressColor(i, address);
     address += inc * _nbCols;
@@ -262,27 +254,27 @@ void Device::MemoryEditorGroup::addEditor(MemoryEditor *editor)
 
 void Device::MemoryEditorGroup::setReadOnly(bool readOnly)
 {
-  for (uint i=0; i<_editors.count(); i++)
+  for (int i=0; i<_editors.count(); i++)
     _editors[i]->setReadOnly(readOnly);
 }
 
 void Device::MemoryEditorGroup::updateDisplay()
 {
-  for (uint i=0; i<_editors.count(); i++)
+  for (int i=0; i<_editors.count(); i++)
     _editors[i]->updateDisplay();
 }
 
 //-----------------------------------------------------------------------------
 const Device::ActionData Device::ACTION_DATA[Nb_Actions] = {
-  { I18N_NOOP("&Clear"),       "fileclose",         NeedWrite },
-  { I18N_NOOP("&Zero"),        0,                   NeedWrite },
-  { I18N_NOOP("For checksum check"), 0,             NeedWrite },
-  { I18N_NOOP("Re&load"),      "reload",            SeparatorAfter | NeedModified },
-  { I18N_NOOP("&Program"),     "piklab_burnchip",   NeedProgrammer },
-  { I18N_NOOP("&Verify"),      "piklab_verifychip", NeedProgrammer },
-  { I18N_NOOP("&Read"),        "piklab_readchip",   NeedProgrammer | NeedWrite },
-  { I18N_NOOP("&Erase"),       "piklab_erasechip",  NeedProgrammer },
-  { I18N_NOOP("&Blank Check"), "piklab_blankcheck", NeedProgrammer }
+  { I18N_NOOP("&Clear"),       "edit-clear",      NeedWrite },
+  { I18N_NOOP("&Zero"),        0,                 NeedWrite },
+  { I18N_NOOP("For checksum check"), 0,           NeedWrite },
+  { I18N_NOOP("Re&load"),      "view-refresh",    SeparatorAfter | NeedModified },
+  { I18N_NOOP("&Program"),     "arrow-down",      NeedProgrammer },
+  { I18N_NOOP("&Verify"),      "dialog-ok-apply", NeedProgrammer },
+  { I18N_NOOP("&Read"),        "arrow-up",        NeedProgrammer | NeedWrite },
+  { I18N_NOOP("&Erase"),       "draw-eraser",     NeedProgrammer },
+  { I18N_NOOP("&Blank Check"), "dialog-ok",       NeedProgrammer }
 };
 
 Device::MemoryTypeEditor::MemoryTypeEditor(const HexView *hexview, Device::Memory &memory,
@@ -301,8 +293,8 @@ void Device::MemoryTypeEditor::init(bool first)
   _title = new PopupButton(this);
   for (uint i=0; i<Nb_Actions; i++) {
     if ( hasAction(Action(i)) ) {
-      _actions[i] = new KAction(i18n(ACTION_DATA[i].label), ACTION_DATA[i].icon, 0,
-                                this, SLOT(doAction()), MainWindow::self().actionCollection());
+      _actions[i] = new KAction(KIcon(ACTION_DATA[i].icon), i18n(ACTION_DATA[i].label), this);
+      connect(_actions[i], SIGNAL(triggered()), this, SLOT(doAction()));
       addAction(_actions[i]);
     }
     if ( ACTION_DATA[i].properties & SeparatorAfter ) _title->appendSeparator();
@@ -335,7 +327,7 @@ void Device::MemoryTypeEditor::doAction()
 void Device::MemoryTypeEditor::doAction(Action action)
 {
   if ( (ACTION_DATA[action].properties & NeedProgrammer)
-       && !Programmer::manager->initProgramming(false, Programmer::ProgramAction::Nb_Types) ) return;
+       && !Programmer::manager->initProgramming(Programmer::ProgramAction::Nb_Types) ) return;
   bool ok = internalDoAction(action);
   if ( ACTION_DATA[action].properties & NeedProgrammer )
     Programmer::manager->endProgramming();
