@@ -22,7 +22,7 @@ class Group : public Device::Group<Data>
 public:
   virtual QString name() const { return "mem24"; }
   virtual QString label() const { return i18n("Serial Memory 24"); }
-  virtual Device::Memory *createMemory(const Device::Data &data) const;
+  virtual std::auto_ptr<Device::Memory> createMemory(const Device::Data &data) const;
   virtual QString informationHtml(const Device::Data &data) const;
   virtual QPixmap memoryGraph(const Device::Data &data) const;
 
