@@ -36,19 +36,18 @@ const Pic::MemoryRangeType::Data Pic::MemoryRangeType::DATA[Nb_Types] = {
 const Pic::Architecture::Data Pic::Architecture::DATA[Nb_Types] = {
 //  name family_label nbBytesPC nbBytesWord nbBitsRegister registerBankLength
 //  {Code, Cal, UserID, DevId, Conf, EEPROM, DebugVec, HardStack, CalBackup, Program Executive}
-//  properties nominalVdd
-  { "baseline", I18N_NOOP("Baseline Family"),  0, 2, 8, 0x020, { 12, 12, 12, 12, 12,  8, 12,  0, 12,  0 },  NoArchitectureProperty, 5.0 }, // 9, 10, 11 or 12-bit program counter
-  { "midrange", I18N_NOOP("Mid-Range Family"), 13, 2, 8, 0x080, { 14, 14, 14, 14, 14,  8, 14,  0, 14,  0 },  MaybeSelfWrite, 5.0 }, // max eeprom: 256 words
-  { "emidrange", I18N_NOOP("Enhance Mid-Range Family"), 13, 2, 8, 0x080, { 14, 14, 14, 14, 14,  8, 14,  0, 14,  0 },  MaybeSelfWrite, 5.0 }, // max eeprom: 256 words
-  { "17C", I18N_NOOP("17C Family"),      16, 2, 8, 0x100, { 16,  0,  0,  0, 16,  8,  0,  0,  0,  0 },  RandomMemoryAccess,     5.0 },
-  { "18C", I18N_NOOP("18C Family"),      21, 2, 8, 0x100, { 16,  8,  8,  8,  8,  8, 16,  0,  8,  0 },  PackedHex | RandomMemoryAccess, 5.0 },
-  { "18F", I18N_NOOP("18F Family"),      21, 2, 8, 0x100, { 16,  8,  8,  8,  8,  8, 16,  0,  8,  0 },  PackedHex | RandomMemoryAccess | MaybeSelfWrite, 5.0 },
-  { "18J", I18N_NOOP("18J Family"),      21, 2, 8, 0x100, { 16,  8,  8,  8,  8,  8, 16,  0,  8,  0 },  PackedHex | RandomMemoryAccess | SelfWrite | JFamily, 3.3 },
-
-  { "24F", I18N_NOOP("24F Family"),      23, 4, 16, 0x800, { 24,  0,  0, 16, 16,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 },
-  { "24H", I18N_NOOP("24H Family"),      23, 4, 16, 0x800, { 24,  0,  8, 16,  8,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 },
-  { "30F", I18N_NOOP("30F Family"),      23, 4, 16, 0xA00, { 24,  0, 24, 16, 16, 16, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite, 5.0 }, // dsPIC: eeprom max = 2 kwords = 4 kbytes
-  { "33F", I18N_NOOP("33F Family"),      23, 4, 16, 0x800, { 24,  0, 16, 16, 16,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 }
+//  properties nominalVdd devIdMask
+  { "baseline",  I18N_NOOP("Baseline Family"),            0, 2,  8, 0x020, { 12, 12, 12, 12, 12,  8, 12, 0, 12,  0 }, NoArchitectureProperty,                          5.0, 0xFFE0 }, // 9, 10, 11 or 12-bit program counter
+  { "midrange",  I18N_NOOP("Mid-Range Family"),          13, 2,  8, 0x080, { 14, 14, 14, 14, 14,  8, 14, 0, 14,  0 }, MaybeSelfWrite,                                  5.0, 0xFFE0 }, // max eeprom: 256 words
+  { "emidrange", I18N_NOOP("Enhanced Mid-Range Family"), 13, 2,  8, 0x080, { 14, 14, 14, 14, 14,  8, 14, 0, 14,  0 }, MaybeSelfWrite,                                  5.0, 0xFFE0 }, // max eeprom: 256 words
+  { "17C",       I18N_NOOP("17C Family"),                16, 2,  8, 0x100, { 16,  0,  0,  0, 16,  8,  0, 0,  0,  0 }, RandomMemoryAccess,                              5.0, 0xFFE0 },
+  { "18C",       I18N_NOOP("18C Family"),                21, 2,  8, 0x100, { 16,  8,  8,  8,  8,  8, 16, 0,  8,  0 }, PackedHex | RandomMemoryAccess,                  5.0, 0xFFE0 },
+  { "18F",       I18N_NOOP("18F Family"),                21, 2,  8, 0x100, { 16,  8,  8,  8,  8,  8, 16, 0,  8,  0 }, PackedHex | RandomMemoryAccess | MaybeSelfWrite, 5.0, 0xFFE0 },
+  { "18J",       I18N_NOOP("18J Family"),                21, 2,  8, 0x100, { 16,  8,  8,  8,  8,  8, 16, 0,  8,  0 }, PackedHex | RandomMemoryAccess | SelfWrite,      3.3, 0xFFE0 },
+  { "24F",       I18N_NOOP("24F Family"),                23, 4, 16, 0x800, { 24,  0,  0, 16, 16,  0, 24, 0,  0, 24 }, RandomMemoryAccess | SelfWrite,                  3.3, 0xFFFF },
+  { "24H",       I18N_NOOP("24H Family"),                23, 4, 16, 0x800, { 24,  0,  8, 16,  8,  0, 24, 0,  0, 24 }, RandomMemoryAccess | SelfWrite,                  3.3, 0xFFFF },
+  { "30F",       I18N_NOOP("30F Family"),                23, 4, 16, 0xA00, { 24,  0, 24, 16, 16, 16, 24, 0,  0, 24 }, RandomMemoryAccess | SelfWrite,                  5.0, 0xFFFF }, // dsPIC: eeprom max = 2 kwords = 4 kbytes
+  { "33F",       I18N_NOOP("33F Family"),                23, 4, 16, 0x800, { 24,  0, 16, 16, 16,  0, 24, 0,  0, 24 }, RandomMemoryAccess | SelfWrite,                  3.3, 0xFFFF }
 };
 
 const Pic::Checksum::Algorithm::Data Pic::Checksum::Algorithm::DATA[Nb_Types] = {
@@ -77,6 +76,7 @@ const Pic::Feature::Data Pic::Feature::DATA[Nb_Types] = {
 //-----------------------------------------------------------------------------
 Pic::Data::Data()
 {
+  _progFamilyIndex = -1;
   _registersData.reset(new RegistersData(*this));
   FOR_EACH(ProgVoltageType, type) {
     _voltages[type].min = 0.0;
@@ -146,6 +146,11 @@ QString Pic::Data::fname(Device::Special special) const
   return s;
 }
 
+BitValue Pic::Data::devIdMask() const
+{
+  return architecture().data().devIdMask;
+}
+
 bool Pic::Data::matchId(BitValue rawId, Device::IdData &idata) const
 {
   if ( !isPresent(MemoryRangeType::DeviceId) ) return false;
@@ -161,27 +166,28 @@ bool Pic::Data::matchId(BitValue rawId, Device::IdData &idata) const
       case Architecture::P18C:
       case Architecture::P18F:
       case Architecture::P18J:
-        nid = rawId.clearMaskBits(0x1F);
+        nid = rawId;
         idata.revision = rawId.maskWith(0x1F);
         break;
       case Architecture::P24F:
-        nid = (rawId >> 16).maskWith(0x3FFF);
+        nid = (rawId >> 16);
         idata.revision = (rawId >> 6).maskWith(0x7);
         idata.minorRevision = rawId.maskWith(0x7);
         break;
       case Architecture::P30F:
-        nid = (rawId >> 16).maskWith(0xFFFF);
+        nid = (rawId >> 16);
         idata.revision = (rawId >> 6).maskWith(0x3F);
         idata.minorRevision = rawId.maskWith(0x3F);
         idata.process = (rawId >> 12).maskWith(0xF);
         break;
       case Architecture::P24H:
       case Architecture::P33F:
-        nid = (rawId >> 16).maskWith(0xFFFF);
+        nid = (rawId >> 16);
         idata.revision = rawId.maskWith(0xFFFF); // ??
         break;
       case Architecture::Nb_Types: ASSERT(false); break;
     }
+    nid = nid.maskWith(devIdMask());
     if ( nid==it.data() ) return true;
   }
   return false;
@@ -339,31 +345,35 @@ bool Pic::Data::isGotoInstruction(BitValue instruction) const
 
 uint Pic::Data::nbWordsWriteAlignment(MemoryRangeType type) const
 {
-  if (type != MemoryRangeType::Code
-       && type != MemoryRangeType::ProgramExecutive) return 1;
-  if (_nbWordsCodeWrite == 0) {
-    switch (architecture().type()) {
-      case Architecture::P24F:
-      case Architecture::P24H:
-      case Architecture::P33F: return 64;
-      case Architecture::P30F: return 32; // ?
-      default:                 return 16; // default ??
-    }
-  } else return _nbWordsCodeWrite;
+  if (type != MemoryRangeType::Code && type != MemoryRangeType::ProgramExecutive) return 1;
+  if (progFamilyData() != NULL) return progFamilyData()->codeLatches / nbBytesWord(type);
+  if (_nbWordsCodeWrite != 0) return _nbWordsCodeWrite;
+  switch (architecture().type()) {
+    case Architecture::P24F:
+    case Architecture::P24H:
+    case Architecture::P33F: return 64;
+    case Architecture::P30F: return 32; // ?
+    default:                 return 16; // default ??
+  }
 }
 
 uint Pic::Data::nbWordsRowEraseAlignment(MemoryRangeType type) const
 {
-  if (type != MemoryRangeType::Code
-      && type != MemoryRangeType::ProgramExecutive) return 1;
-  if (_nbWordsCodeRowErase == 0) {
-    switch (architecture().type()) {
-      case Architecture::P24F:
-      case Architecture::P24H:
-      case Architecture::P33F: return 512;
-      default:                 return 16; // default ??
-    }
-  } else return _nbWordsCodeRowErase;
+  if (type != MemoryRangeType::Code && type != MemoryRangeType::ProgramExecutive) return 1;
+  if (progFamilyData() != NULL) return progFamilyData()->rowEraseLatches / nbBytesWord(type);
+  if (_nbWordsCodeRowErase != 0) return _nbWordsCodeRowErase;
+  switch (architecture().type()) {
+    case Architecture::P24F:
+    case Architecture::P24H:
+    case Architecture::P33F: return 512;
+    default:                 return 16; // default ??
+  }
+}
+
+const Pic::ProgFamilyData* Pic::Data::progFamilyData() const
+{
+  if (_progFamilyIndex == -1) return NULL;
+  return &PROG_FAMILY_DATA[_progFamilyIndex];
 }
 
 //----------------------------------------------------------------------------
@@ -427,6 +437,7 @@ QDataStream &Pic::operator <<(QDataStream &s, const Pic::Data &data)
   s << static_cast<const Pic::RegistersData &>(*data._registersData);
   s << data._nbWordsCodeWrite << data._nbWordsCodeRowErase;
   s << Q_UINT8(data._selfWrite);
+  s << Q_INT8(data._progFamilyIndex);
   return s;
 }
 QDataStream &Pic::operator >>(QDataStream &s, Pic::Data &data)
@@ -440,8 +451,11 @@ QDataStream &Pic::operator >>(QDataStream &s, Pic::Data &data)
   s >> data._calibration;
   s >> static_cast<Pic::RegistersData &>(*data._registersData);
   s >> data._nbWordsCodeWrite >> data._nbWordsCodeRowErase;
-  Q_UINT8 sw;
-  s >> sw;
-  data._selfWrite = sw;
+  Q_UINT8 v;
+  s >> v;
+  data._selfWrite = v;
+  Q_INT8 sv;
+  s >> sv;
+  data._progFamilyIndex = sv;
   return s;
 }
