@@ -14,6 +14,7 @@
 #include "common/common/global.h"
 #include "common/common/bitvalue.h"
 #include "devices/base/generic_device.h"
+#include "pic_prog_family.h"
 
 namespace Pic
 {
@@ -48,8 +49,7 @@ BEGIN_DECLARE_ENUM(MemoryRangeType)
 END_DECLARE_ENUM(MemoryRangeType, MemoryRangeTypeData)
 
 enum ArchitectureProperty {
-  NoArchitectureProperty = 0, PackedHex = 1, RandomMemoryAccess = 2,
-  MaybeSelfWrite = 4, SelfWrite = 8, JFamily = 16, KFamily = 32
+  NoArchitectureProperty = 0, PackedHex = 1, RandomMemoryAccess = 2, MaybeSelfWrite = 4, SelfWrite = 8
 };
 Q_DECLARE_FLAGS(ArchitectureProperties, ArchitectureProperty)
 Q_DECLARE_OPERATORS_FOR_FLAGS(ArchitectureProperties)
@@ -63,6 +63,7 @@ struct ArchitectureData {
   uint nbBits[MemoryRangeType::Nb_Types];  // nb bits per word
   ArchitectureProperties properties;
   double nominalVdd;
+  uint devIdMask;
 };
 BEGIN_DECLARE_ENUM(Architecture)
   Baseline = 0, MidRange, EMidRange, P17C, P18C, P18F, P18J, P24F, P24H, P30F, P33F
@@ -124,16 +125,18 @@ public:
   Architecture architecture() const { return _architecture; }
   bool is18Family() const { return ( _architecture==Architecture::P18C || _architecture==Architecture::P18F || _architecture==Architecture::P18J); }
   bool is16bitFamily() const { return ( _architecture.data().nbBitsRegister==16 ); }
-  const VoltageData voltage(ProgVoltageType type) const { return _voltages[type]; }
+  VoltageData voltage(ProgVoltageType type) const { return _voltages[type]; }
   virtual bool canWriteCalibration() const { return isWritable(MemoryRangeType::Cal); }
   bool checkCalibration(const Device::Array &data, QString *message = 0) const;
   const QMap<Device::Special, BitValue> &ids() const { return _ids; }
+  BitValue devIdMask() const;
   virtual bool matchId(BitValue rawId, Device::IdData &data) const;
   QStringList idNames(const QMap<QString, Device::IdData> &ids) const;
   const QMap<QString, Checksum::Data> &checksums() const { return _checksums; }
   const RegistersData &registersData() const;
   const CalibrationData &calibrationData() const { return _calibration; }
   bool isCalibrationAtCodeEnd() const;
+  const ProgFamilyData* progFamilyData() const;
 
   bool hasFeature(Feature feature, bool *unknown = 0) const;
   BitValue nopInstruction() const { return 0x0; }
@@ -142,6 +145,7 @@ public:
 
 private:
   Architecture                           _architecture;
+  int                                    _progFamilyIndex;
   QMap<Device::Special, BitValue>        _ids;
   uint                                   _nbBitsPC;
   uint                                   _nbWordsCodeWrite;
