@@ -217,7 +217,8 @@ const Pic::Config::Data Pic::Config::DATA[] = {
   { { "GCP", I18N_NOOP("General code segment read-protection") }, MemoryRange, { { 0, 0 } } },
   { { "GWRP", I18N_NOOP("General code segment write-protection") }, MemoryRange, { { 0, 0 } } },
   { { "COE", I18N_NOOP("Reset into clip-on emulation mode") }, Toggle, { { 0, 0 } } },
-  { { "ICS", I18N_NOOP("ICD communication channel") }, Pins, { { 0, 0 } } },
+  { { "ICS", I18N_NOOP("ICD communication channel") }, Pins, {
+    { "Undefined", I18N_NOOP("Undefined") }, { 0, 0 } } },
 
   { { "USBDIV", I18N_NOOP("USB clock (PLL divided by)") }, ValueUInt, {
     { "1", I18N_NOOP("not divided") }, { 0, 0 } } },
@@ -310,6 +311,13 @@ const Pic::Config::Data Pic::Config::DATA[] = {
   { { "BOREN", I18N_NOOP("Brown-out reset") }, Fixed, {
     { "Off", I18N_NOOP("Off") },
     { "On", I18N_NOOP("Enabled in hardware") }, { 0, 0 } } },
+  { { "UVREG", I18N_NOOP("Internal USB Regulator") }, Toggle, { { 0, 0 } } },
+  { { "WPFP", I18N_NOOP("Protected Code Segment Boundary Page") }, RawValue, { { 0, 0 } } },
+  { { "WP", I18N_NOOP("Segment Write Protection") }, Toggle, { { 0, 0 } } },
+  { { "WPCFG", I18N_NOOP("Configuration Word Code Page Protection") }, Toggle, { { 0, 0 } } },
+  { { "WPEND", I18N_NOOP("Segment Write Protection End Page") }, Fixed, {
+    { "EndProtected", I18N_NOOP("Protected segment ends at last code page") },
+    { "BeginProtected", I18N_NOOP("Protected segment starts at first code page") }, { 0, 0 } } },
 
   { { 0, 0 }, Fixed, { { 0, 0 } } }
 };
@@ -370,6 +378,7 @@ bool Pic::Config::checkValueName(const QString &mask, const QString &name) const
   QString pinRegexp = "[A-Z]+\\d*(/[A-Z]+\\d*)?";
   switch (data.type) {
     case Fixed: break;
+    case RawValue: return true;
     case ValueDouble: {
       bool ok;
       (void)name.toDouble(&ok);
@@ -418,6 +427,7 @@ QString Pic::Config::valueLabel(const QString &mask, const QString &name)
   const Data &data = DATA[masks()[mask].index];
   switch (data.type) {
     case Fixed:
+    case RawValue:
     case ValueDouble:
     case ValueUInt:
     case Pin:
@@ -437,6 +447,12 @@ QString Pic::Config::valueLabel(const QString &mask, const QString &name)
   return name;
 }
 
+bool Pic::Config::isRawValue(const QString& mask) const
+{
+  const Data &data = DATA[masks()[mask].index];
+  return data.type == RawValue;
+}
+
 BitValue Pic::Config::Word::usedMask() const
 {
   BitValue mask = 0x0;
