@@ -23,7 +23,7 @@ class Group : public Device::Group<Data>
 public:
   virtual QString name() const { return "pic"; }
   virtual QString label() const { return i18n("PIC"); }
-  virtual Device::Memory *createMemory(const Device::Data &data) const;
+  virtual std::auto_ptr<Device::Memory> createMemory(const Device::Data &data) const;
   virtual QString informationHtml(const Device::Data &data) const;
   virtual QPixmap memoryGraph(const Device::Data &data) const;
 
