@@ -131,7 +131,7 @@ bool Programmer::PicBase::initProgramming(Task)
     _deviceMemory->setArray(Pic::MemoryRangeType::Config, data);
     _hasProtectedCode = _deviceMemory->isProtected(Pic::Protection::ProgramProtected, Pic::MemoryRangeType::Code);
     _hasProtectedEeprom = _deviceMemory->isProtected(Pic::Protection::ProgramProtected, Pic::MemoryRangeType::Eeprom);
-    log(Log::DebugLevel::Normal, QString("  protected: code=%1 data=%2")
+    log(Log::DebugLevel::Extra, QString("  protected: code=%1 data=%2")
                           .arg(_hasProtectedCode ? "true" : "false").arg(_hasProtectedEeprom ? "true" : "false"));
     // read calibration
     if ( !readCalibration() ) return false;
@@ -470,6 +470,7 @@ void Programmer::PicBase::prepareMemoryForWriting(Pic::Memory& memory, bool issu
     }
     memory.setDebugOn(group().isDebugger());
   }
+
   if (memory.hasJTagOn()) {
     if (issueWarnings) log(Log::LineType::Warning, i18n("Disabling JTAGEN configuration bit."));
     memory.setJTagOn(false);
