@@ -12,6 +12,7 @@
 
 #include "xml_to_data/device_xml_to_data.h"
 #include "common/common/misc.h"
+#include "common/common/number.h"
 #include "devices/pic/base/pic_config.h"
 #include "devices/pic/base/pic_register.h"
 
@@ -25,16 +26,35 @@ private:
 bool getVoltages(ProgVoltageType type, QDomElement element)
 {
   QDomElement voltages = findUniqueElement(element, "voltages", "name", type.key());
-  if ( voltages.isNull() ) return false;
-  bool ok1, ok2, ok3;
-  data()->_voltages[type].min = voltages.attribute("min").toDouble(&ok1);
-  data()->_voltages[type].max = voltages.attribute("max").toDouble(&ok2);
-  data()->_voltages[type].nominal = voltages.attribute("nominal").toDouble(&ok3);
-  if ( !ok1 || !ok2 || !ok3 ) qFatal(QString("Cannot extract voltage value for \"%1\"").arg(type.key()));
-  if ( data()->_voltages[type].min>data()->_voltages[type].max
-       || data()->_voltages[type].nominal<data()->_voltages[type].min
-       || data()->_voltages[type].nominal>data()->_voltages[type].max )
-    qFatal("Inconsistent voltages order");
+  if (data()->progFamilyData() != NULL) {
+    if (!voltages.isNull()) qFatal("voltages already defines in prog family");
+    if (type==ProgVoltageType::VddWrite) {
+      data()->_voltages[type].min = double(data()->progFamilyData()->vddMin) / 1000;
+      data()->_voltages[type].max = double (data()->progFamilyData()->vddMax) / 1000;
+      data()->_voltages[type].nominal = double(data()->progFamilyData()->vddDef) / 1000;
+    }
+    if (type==ProgVoltageType::Vpp) {
+      data()->_voltages[type].min = double(data()->progFamilyData()->vppMin) / 1000;
+      data()->_voltages[type].max = double(data()->progFamilyData()->vppMax) / 1000;
+      data()->_voltages[type].nominal = double(data()->progFamilyData()->vppDef) / 1000;
+    }
+    if (type==ProgVoltageType::VddBulkErase) {
+      data()->_voltages[type].min = double(data()->progFamilyData()->eraseMin) / 1000;
+      data()->_voltages[type].max = double(data()->progFamilyData()->vddMax) / 1000;
+      data()->_voltages[type].nominal = double(data()->progFamilyData()->vddDef) / 1000;
+    }
+  } else {
+    if ( voltages.isNull() ) return false;
+    bool ok1, ok2, ok3;
+    data()->_voltages[type].min = voltages.attribute("min").toDouble(&ok1);
+    data()->_voltages[type].max = voltages.attribute("max").toDouble(&ok2);
+    data()->_voltages[type].nominal = voltages.attribute("nominal").toDouble(&ok3);
+    if ( !ok1 || !ok2 || !ok3 ) qFatal(QString("Cannot extract voltage value for \"%1\"").arg(type.key()));
+  }
+
+  if (data()->_voltages[type].min > data()->_voltages[type].max) qFatal("Inconsistent voltages order (min > max)");
+  if (data()->_voltages[type].nominal < data()->_voltages[type].min) qFatal("Inconsistent voltages order (nominal < min)");
+  if (data()->_voltages[type].nominal > data()->_voltages[type].max) qFatal("Inconsistent voltages order (nominal > max)");
   return true;
 }
 
@@ -77,22 +97,24 @@ bool getMemoryRange(MemoryRangeType type, QDomElement element)
       if (data()->_calibration.opcode != 0) qFatal("Calibration opcode should be 0");
     }
   }
+
   QString wwa = range.attribute("word_write_align");
   QString wea = range.attribute("word_erase_align");
   if ( type==MemoryRangeType::Code ) {
     data()->_nbWordsCodeWrite = 0; // default
     data()->_nbWordsCodeRowErase = 0; // default
-    if ( !wwa.isEmpty() ) {
-      data()->_nbWordsCodeWrite = wwa.toUInt(&ok);
-      if ( !ok || data()->_nbWordsCodeWrite==0 || (data()->_nbWordsCodeWrite%4)!=0 ) qFatal("Malformed word write align");
-    } else if ( data()->_architecture==Architecture::P18F || data()->_architecture==Architecture::P18J ) {
-      qFatal("Missing word write align");
-    }
-    if ( !wea.isEmpty() ) {
-      data()->_nbWordsCodeRowErase = wea.toUInt(&ok);
-      if ( !ok || (data()->_nbWordsCodeRowErase%4)!=0 ) qFatal("Malformed word erase align");
-    } else if ( data()->_architecture==Architecture::P18F || data()->_architecture==Architecture::P18J ) {
-      qFatal("Missing word erase align");
+    if (data()->progFamilyData() != NULL) {
+      if (!wwa.isEmpty()) qFatal("word write align already defined in prog family");
+      if (!wwa.isEmpty()) qFatal("word erase align already defined in prog family");
+    } else {
+      if ( !wwa.isEmpty() ) {
+        data()->_nbWordsCodeWrite = wwa.toUInt(&ok);
+        if ( !ok || data()->_nbWordsCodeWrite==0 || (data()->_nbWordsCodeWrite%4)!=0 ) qFatal("Malformed word write align");
+      } else if ( data()->_architecture==Architecture::P18F || data()->_architecture==Architecture::P18J ) qFatal("Missing word write align");
+      if ( !wea.isEmpty() ) {
+        data()->_nbWordsCodeRowErase = wea.toUInt(&ok);
+        if ( !ok || (data()->_nbWordsCodeRowErase%4)!=0 ) qFatal("Malformed word erase align");
+      } else if ( data()->_architecture==Architecture::P18F || data()->_architecture==Architecture::P18J ) qFatal("Missing word erase align");
     }
   } else if ( !wwa.isEmpty() || !wea.isEmpty() ) qFatal("word align should not be defined for this memory range");
   return true;
@@ -154,6 +176,7 @@ Pic::Config::Mask toConfigMask(QDomElement mask, BitValue pmask)
   cmask.value = fromHexLabel(mask.attribute("value"), nbChars, &ok);
   if ( !ok || cmask.value==0 || cmask.value>data()->mask(MemoryRangeType::Config) )
     qFatal(QString("Malformed mask value in mask %1").arg(mask.attribute("name")));
+
   //QStringList names;
   QDomNode child = mask.firstChild();
   while ( !child.isNull() ) {
@@ -161,6 +184,7 @@ Pic::Config::Mask toConfigMask(QDomElement mask, BitValue pmask)
     child = child.nextSibling();
     if ( value.isNull() ) continue;
     if ( value.nodeName()!="value" ) qFatal(QString("Non value child in mask %1").arg(cmask.name));
+    if (data()->_config->isRawValue(cmask.name)) qFatal(QString("Raw value mask %1 cannot have explicit valued").arg(cmask.name));
     if ( value.attribute("value")=="default" ) {
       if ( !defName.isEmpty() ) qFatal(QString("Default value already defined for mask %1").arg(cmask.name));
       defName = value.attribute("name");
@@ -179,11 +203,21 @@ Pic::Config::Mask toConfigMask(QDomElement mask, BitValue pmask)
     processName(cmask, pmask, cvalue);
     cmask.values.append(cvalue);
   }
+
+  if (data()->_config->isRawValue(cmask.name)) {
+    uint nb = ::nbChars(NumberBase::Hex, cmask.value.toUInt());
+    for (BitValue::const_iterator it=cmask.value.begin(); it!=cmask.value.end(); ++it) {
+      Config::Value cvalue;
+      cvalue.value = *it;
+      cvalue.name = toHexLabel(*it, nb);
+      cmask.values.append(cvalue);
+    }
+  }
+
   // add default values
   if ( !defName.isEmpty() ) {
     uint nb = 0;
-    BitValue::const_iterator it;
-    for (it=cmask.value.begin(); it!=cmask.value.end(); ++it) {
+    for (BitValue::const_iterator it=cmask.value.begin(); it!=cmask.value.end(); ++it) {
       if ( hasValue(cmask, *it) ) continue; // already set
       nb++;
       Config::Value cvalue;
@@ -402,6 +436,15 @@ virtual void processDevice(QDomElement device)
     }
   }
 
+  // prog family
+  QString progFamily = device.attribute("prog_family");
+  if (!progFamily.isEmpty()) {
+    data()->_progFamilyIndex = findProgFamilyIndex(progFamily);
+    if (data()->_progFamilyIndex == -1) qFatal("Unknown prog family");
+  } else {
+    data()->_progFamilyIndex = -1;
+  }
+
   // voltages
   QStringList names;
   FOR_EACH(ProgVoltageType, vtype) {
@@ -426,7 +469,7 @@ virtual void processDevice(QDomElement device)
   FOR_EACH(MemoryRangeType, i) {
     names += i.key();
     if ( !getMemoryRange(i, device) ) continue;
-     if ( !(data()->_ranges[i].properties & Programmable) ) continue;
+    if ( !(data()->_ranges[i].properties & Programmable) ) continue;
     for(MemoryRangeType k; k<i; ++k) {
       if ( !(data()->_ranges[k].properties & Present)
            || !(data()->_ranges[k].properties & Programmable) ) continue;
@@ -488,8 +531,7 @@ virtual void processDevice(QDomElement device)
     const Config::Word &word = data()->_config->_words[i];
     for (uint j=0; j<uint(word.masks.count()); j++) {
       const Config::Mask &mask = word.masks[j];
-      BitValue::const_iterator it;
-      for (it=mask.value.begin(); it!=mask.value.end(); ++it)
+      for (BitValue::const_iterator it=mask.value.begin(); it!=mask.value.end(); ++it)
         if ( !hasValue(mask, *it) ) qFatal(QString("Value %1 not defined in mask %2").arg(toHexLabel(*it, data()->nbCharsWord(MemoryRangeType::Config))).arg(mask.name));
     }
   }
