@@ -14,17 +14,6 @@
 #include "coff/base/text_coff.h"
 #include "gui_debug_manager.h"
 
-//----------------------------------------------------------------------------
-void Breakpoint::updateActions(const Data *data)
-{
-  bool hasBreakpoint = (data ? Breakpoint::list().contains(*data) : false);
-  Main::action("toggle_breakpoint")->setText(hasBreakpoint ? i18n("Remove breakpoint") : i18n("Set breakpoint"));
-  Main::action("toggle_breakpoint")->setEnabled(data);
-  bool isActive = (hasBreakpoint ? Breakpoint::list().state(*data)==Breakpoint::Active : false);
-  Main::action("enable_breakpoint")->setText(!isActive ? i18n("Enable breakpoint") : i18n("Disable breakpoint"));
-  Main::action("enable_breakpoint")->setEnabled(Debugger::manager->coff() && hasBreakpoint);
-}
-
 //----------------------------------------------------------------------------
 Breakpoint::ListViewItem::ListViewItem(ListView *parent, const Data &data)
   : KListViewItem(parent), _data(data)
@@ -42,8 +31,10 @@ Breakpoint::View::View(QWidget *parent)
           SLOT(contextMenu(Q3ListViewItem *, const QPoint &, int)));
   _listview->setAllColumnsShowFocus(true);
   _listview->addColumn(i18n("Status"));
-  _listview->addColumn(i18n("Location"));
+  _listview->addColumn(i18n("File"));
+  _listview->addColumn(i18n("Line"));
   _listview->addColumn(i18n("Address"));
+  _listview->setSorting(2);
   top->addWidget(_listview);
 }
 
@@ -55,11 +46,12 @@ void Breakpoint::View::updateView()
     const Data &data = Breakpoint::list().data(i);
     KListViewItem *item = new ListViewItem(_listview, data);
     item->setPixmap(0, TextEditor::pixmap(Debugger::manager->breakpointType(data)));
-    item->setText(1, data.url.filename() + ":" + QString::number(data.line));
+    item->setText(1, data.url.filename());
+    item->setText(2, QString::number(data.line));
     Address address = Breakpoint::list().address(data);
-    if ( address.isValid() ) item->setText(2, toHexLabelAbs(address));
-    else if ( Debugger::manager->coff() ) item->setText(2, i18n("Non-code breakpoint"));
-    else item->setText(2, "---");
+    if ( address.isValid() ) item->setText(3, toHexLabelAbs(address));
+    else if ( Debugger::manager->coff() ) item->setText(3, i18n("Non-code breakpoint"));
+    else item->setText(3, "---");
   }
 }
 
@@ -85,8 +77,16 @@ void Breakpoint::View::itemClicked(Q3ListViewItem *item)
 void Breakpoint::View::contextMenu(Q3ListViewItem *item, const QPoint &pos, int)
 {
   _currentData = (item != NULL ? &static_cast<ListViewItem *>(item)->data() : NULL);
-  updateActions(_currentData);
-  QMenu* popup = Main::popup("breakpoint_context_menu");
-  if (popup != NULL) popup->exec(pos);
+  PopupMenu pop;
+  pop.addTitle(i18n("Breakpoints"));
+  QAction* a  = pop.addAction(i18n("Remove breakpoint"), Debugger::manager, SLOT(toggleBreakpoint()));
+  a->setEnabled(_currentData != NULL);
+  const bool isActive = (_currentData != NULL ? Breakpoint::list().state(*_currentData)==Breakpoint::Active : false);
+  a = pop.addAction(!isActive ? i18n("Enable breakpoint") : i18n("Disable breakpoint"), Debugger::manager, SLOT(toggleEnableBreakpoint()));
+  const Coff::TextObject *coff = Debugger::manager->coff();
+  a->setEnabled(_currentData != NULL && coff != NULL);
+  a = pop.addAction(KIcon("edit-delete"), i18n("Clear"), Debugger::manager, SLOT(clearBreakpoints()));
+  a->setEnabled(Breakpoint::list().count() > 0);
+  pop.exec(pos);
   _currentData = NULL;
 }
