@@ -13,30 +13,31 @@
 #include <qdir.h>
 #include <klibloader.h>
 #include <kparts/part.h>
+#include <kservice.h>
 #include <kde_terminal_interface.h>
 
 #include "common/common/misc.h"
 #include "common/gui/global_ui.h"
 
 ConsoleView::ConsoleView(QWidget *parent)
-  : QWidget(parent, "console_view"), _initialized(false)
+: QWidget(parent, "console_view"),
+  _initialized(false)
 {}
 
 void ConsoleView::showEvent(QShowEvent *e)
 {
   if ( !_initialized ) {
     _initialized = true;
-    KPluginLoader loader("libkonsolepart");
-    KPluginFactory *factory = loader.factory();
+
     QVBoxLayout *top = new QVBoxLayout(this, 0, 10);
-    if (factory == NULL) {
+    KService::Ptr service = KService::serviceByDesktopName("konsolepart");
+    if (!service) {
       QLabel *label = new QLabel(i18n("Could not find \"konsolepart\"; please install konsole."), this);
       label->show();
       top->addWidget(label);
       return;
     }
-
-    KParts::Part* part = factory->create<KParts::Part>(this);
+    KParts::ReadOnlyPart* part = service->createInstance<KParts::ReadOnlyPart>(this, this, QVariantList());
     ASSERT(part != NULL);
     QWidget* widget = part->widget();
     ASSERT(widget != NULL);
@@ -44,10 +45,6 @@ void ConsoleView::showEvent(QShowEvent *e)
     top->addWidget(widget);
     setFocusProxy(widget);
 
-    TerminalInterface* terminal = qobject_cast<TerminalInterface*>(part);
-    ASSERT(terminal != NULL);
-    terminal->showShellInDir(QDir::home().path());
-
     QWidget::showEvent(e);
   }
 }
