@@ -15,7 +15,7 @@
 #include "devices/base/device_group.h"
 #include "devices/gui/device_group_ui.h"
 #include "progs/list/prog_list.h"
-#include "tools/list/device_info.h"
+#include "progs/list/device_info.h"
 #include "tools/list/tool_list.h"
 #include "common/gui/container.h"
 
