@@ -392,7 +392,7 @@ void EditorManager::contextMenu(int i, const QPoint &p)
   Editor *editor = static_cast<Editor *>(page(i));
   if ( editor==0 ) return;
 
-  std::auto_ptr<KPopupMenu> popup(new KPopupMenu);
+  std::auto_ptr<KMenu> popup(new KMenu);
   popup->addTitle(title(*editor));
   QAction* close = popup->addAction(KIcon("document-close"), i18n("Close"));
   QAction* closeAllOthers = nbEditors()>1 ? popup->addAction(KIcon("document-close"), i18n("Close All Others")) : NULL;
