@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 Nicolas Hadacek <hadacek@kde.org>                  *
+ *   Copyright (C) 2006-2012 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -116,6 +116,10 @@ void Debugger::GuiManager::toggleBreakpoint()
   Breakpoint::list().append(data);
   Breakpoint::list().setAddress(data, address);
   if (_coff != NULL) toggleEnableBreakpoint();
+  else {
+    Editor* editor = Main::currentEditor();
+    if (editor != NULL) editor->statusChanged();
+  }
 }
 
 void Debugger::GuiManager::toggleEnableBreakpoint()
@@ -131,6 +135,15 @@ void Debugger::GuiManager::toggleEnableBreakpoint()
       Breakpoint::list().setState(data, Breakpoint::Active);
     } else Breakpoint::list().setState(data, Breakpoint::Disabled);
   }
+  Editor* editor = Main::currentEditor();
+  if (editor != NULL) editor->statusChanged();
+}
+
+void Debugger::GuiManager::clearBreakpoints()
+{
+  Breakpoint::list().clear();
+  Editor* editor = Main::currentEditor();
+  if (editor != NULL) editor->statusChanged();
 }
 
 void Debugger::GuiManager::updateEditorMarks(TextEditor &editor) const
