@@ -81,5 +81,5 @@ Programmer::Generic *Programmer::GuiManager::createProgrammer(const Device::Data
   std::auto_ptr< ::Hardware::Config> hconfig(group()->hardwareConfig());
   if (hconfig.get() != NULL) hd.name = hconfig->currentHardware(hd.port.type);
   internalCreateProgrammer(data, hd);
-  return _programmer;
+  return _programmer.get();
 }
