@@ -27,8 +27,8 @@ public slots:
   void showAdvancedDialog();
 
 private:
-  virtual const Group& group() const { return Main::programmerGroup(); }
-  virtual bool internalInitProgramming(bool debugging, ProgramAction action);
+  virtual const Group* group() const { return &Main::programmerGroup(); }
+  virtual bool internalInitProgramming(ProgramAction action);
   virtual const Device::Data* device() const { return &Main::deviceData(); }
 };
 
