@@ -20,6 +20,13 @@
 #include "gui_prog_manager.h"
 #include "device_editor.h"
 
+//----------------------------------------------------------------------------
+const Piklab::CmdLineOption OPTIONS[] = {
+  { "+[file]", I18N_NOOP("Optional filenames to be opened upon startup."), NULL },
+  { NULL, NULL, NULL}
+};
+
+//----------------------------------------------------------------------------
 Main::State           Main::_state = Main::Idle;
 EditorManager*        Main::_editorManager = NULL;
 ProjectManager::View* Main::_projectManager = NULL;
@@ -29,6 +36,7 @@ Compile::LogWidget*   Main::_compileLog = NULL;
 Compile::Manager*     Main::_compileManager = NULL;
 ConsoleView*          Main::_consoleView = NULL;
 
+//----------------------------------------------------------------------------
 void Main::setState(State state)
 {
   _state = state;
@@ -84,3 +92,15 @@ const Tool::Group& Main::toolGroup()
 {
   return Compile::Config::toolGroup(project());
 }
+
+void Main::setupApplication(int argc, char** argv)
+{
+  Piklab::AboutData about("piklab", I18N_NOOP("Piklab"),
+                          I18N_NOOP( "Graphical development environment for applications based on PIC and dsPIC microcontrollers."));
+  Piklab::OptionList options(OPTIONS);
+  Piklab::initArgs(about, argc, argv, options);
+  const bool gui = true;
+  Piklab::createApplication(about.appName(), argc, argv, gui, NULL);
+  if (kapp->isSessionRestored() && KMainWindow::canBeRestored(1)) MainWindow::self().restore(1);
+  else MainWindow::self().show();
+}
