@@ -14,6 +14,7 @@
 #include "common/gui/misc_gui.h"
 #include "progs/base/generic_prog.h"
 
+//----------------------------------------------------------------------------
 class EditorManager;
 namespace ProjectManager { class View; }
 class Editor;
@@ -26,6 +27,7 @@ namespace Device { class Data; }
 namespace Tool { class Group; }
 class ConsoleView;
 
+//----------------------------------------------------------------------------
 class Main
 {
 public:
@@ -49,6 +51,8 @@ public:
   static Compile::LogWidget& compileLog() { return *_compileLog; }
   static const Tool::Group& toolGroup();
 
+  static void setupApplication(int argc, char** argv);
+
 private:
   static State                 _state;
   static EditorManager        *_editorManager;
