@@ -114,21 +114,16 @@ void Project::clearFiles()
   clearList("general", "files");
 }
 
-QString Project::toSourceObject(const PURL::Url &url, const QString &extension, Tool::ExecutableType execType) const
-{
-  PURL::Url tmp;
-  if ( extension.isEmpty() ) tmp = url.toFileType(PURL::Object);
-  else tmp = url.toExtension(extension);
-  return tmp.relativeTo(directory(), execType.data().separator);
-}
-
 QStringList Project::objectsForLinker(const QString &extension, Tool::ExecutableType execType) const
 {
   QStringList objs;
   PURL::UrlList files = absoluteFiles();
   // objects files corresponding to src files
   for (PURL::UrlList::const_iterator it=files.begin(); it!=files.end(); ++it)
-    if ( (*it).data().group==PURL::Source ) objs += toSourceObject(*it, extension, execType);
+    if ( (*it).data().group==PURL::Source ) {
+      if (extension.isEmpty()) objs += (*it).toFileType(PURL::Object).filename();
+      else objs += (*it).toExtension(extension).filename();
+    }
   // objects
   for (PURL::UrlList::const_iterator it=files.begin(); it!=files.end(); ++it)
     if ( (*it).fileType()==PURL::Object ) objs += (*it).relativeTo(directory(), execType.data().separator);
