@@ -22,7 +22,7 @@
 void PopupMenu::insertItem(const QString &icon, const QString &label, QObject *receiver, const char *slot)
 {
   QPixmap pixmap = IconLoader::loadIcon(icon, IconLoader::Small);
-  KPopupMenu::insertItem(pixmap, label, receiver, slot, 0, _index);
+  KMenu::insertItem(pixmap, label, receiver, slot, 0, _index);
   _index++;
 }
 
