@@ -20,7 +20,7 @@
 #include "progs/list/prog_list.h"
 
 //-----------------------------------------------------------------------------
-class PopupMenu : public KPopupMenu
+class PopupMenu : public KMenu
 {
 Q_OBJECT
 public:
@@ -130,7 +130,7 @@ public:
 
 private:
   mutable std::auto_ptr<QComboBox> _combo;
-  
+
   virtual QWidget *editWidgetFactory(int) const;
   virtual bool alwaysAcceptEdit(int) const { return true; }
 };
