@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2006 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2005-2012 Nicolas Hadacek <hadacek@kde.org>             *
  *   Copyright (C) 2003-2004 Alain Gibaud <alain.gibaud@free.fr>           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,8 +13,11 @@
 #include <klibloader.h>
 #include <ktexteditor/markinterface.h>
 #include <ktexteditor/smartinterface.h>
+#include <ktexteditor/factory.h>
+#include <ktexteditor/editor.h>
 #include <kxmlguifactory.h>
 #include <kstandarddirs.h>
+#include <kactioncollection.h>
 
 #include "main_global.h"
 #include "gui_debug_manager.h"
@@ -53,6 +56,9 @@ TextEditor::TextEditor(bool withDebugger, QWidget *parent, const char *name)
 
 void TextEditor::init(bool withDebugger)
 {
+  QFontMetrics fm(font());
+  setMinimumHeight(5*fm.height());
+
   KPluginLoader loader("katepart");
   KPluginFactory *factory = loader.factory();
   if (factory == NULL) qFatal("Could not find katepart: Install Kate.");
@@ -119,9 +125,14 @@ void TextEditor::addView()
         // prevent warning: No such XML file ".../.kde/share/apps/piklab/katepartui.rc"
         QFile::copy(katePartUI, katePartLocalUI);
       }
-      v->replaceXMLFile(katePartUI, katePartLocalUI);
+      //v->replaceXMLFile(katePartUI, katePartLocalUI); // does not compile on CentOS 6 (kde 4.3.4)
+      v->setLocalXMLFile(katePartLocalUI);
+      v->setXMLFile(katePartUI);
     }
 
+    v->actionCollection()->addAction("editor_toggle_breakpoint", Debugger::manager, SLOT(toggleBreakpoint()));
+    v->actionCollection()->addAction("editor_enable_breakpoint", Debugger::manager, SLOT(toggleEnableBreakpoint()));
+
     if (_view == NULL) _view = v;
     ASSERT(v != NULL);
     connect(v, SIGNAL(focusIn(KTextEditor::View*)), SLOT(focusIn(KTextEditor::View*)));
@@ -207,7 +218,17 @@ void TextEditor::statusChanged()
   _oldModified = isModified();
   _oldReadOnly = isReadOnly();
   const Breakpoint::Data data(url(), line);
-  Breakpoint::updateActions(&data);
+  updateBreakpointActions(&data);
+}
+
+void TextEditor::updateBreakpointActions(const Breakpoint::Data *data)
+{
+  const bool hasBreakpoint = (data ? Breakpoint::list().contains(*data) : false);
+  _view->action("editor_toggle_breakpoint")->setText(hasBreakpoint ? i18n("Remove breakpoint") : i18n("Set breakpoint"));
+  _view->action("editor_toggle_breakpoint")->setEnabled(data);
+  const bool isActive = (hasBreakpoint ? Breakpoint::list().state(*data)==Breakpoint::Active : false);
+  _view->action("editor_enable_breakpoint")->setText(!isActive ? i18n("Enable breakpoint") : i18n("Disable breakpoint"));
+  _view->action("editor_enable_breakpoint")->setEnabled(Debugger::manager->coff() && hasBreakpoint);
 }
 
 void TextEditor::highlightModeChanged()
@@ -279,6 +300,20 @@ void TextEditor::setBookmarkLines(const QValueList<uint> &lines)
     markInterface->setMark(*it, KTextEditor::MarkInterface::Bookmark);
 }
 
+void TextEditor::configure()
+{
+  KPluginLoader loader("katepart");
+  KPluginFactory *factory = loader.factory();
+  KTextEditor::Factory* kteFactory = qobject_cast<KTextEditor::Factory*>(factory);
+  if (kteFactory == NULL) qFatal("Could not find katepart: Install Kate.");
+  KTextEditor::Editor* editor = kteFactory->editor();
+  if (editor != NULL
+    && editor->configDialogSupported()) {
+    editor->configDialog(&MainWindow::self());
+    editor->writeConfig();
+  }
+}
+
 #if 0
 void TextEditor::slotChangedText()
 {
