@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 Nicolas Hadacek <hadacek@kde.org>                  *
+ *   Copyright (C) 2005-2012 Nicolas Hadacek <hadacek@kde.org>             *
  *   Copyright (C) 2003-2004 Alain Gibaud <alain.gibaud@free.fr>           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,6 +41,7 @@ public:
   virtual bool eventFilter(QObject *o, QEvent *e);
   virtual QValueList<uint> bookmarkLines() const;
   virtual void setBookmarkLines(const QValueList<uint> &lines);
+  static void configure();
 
 public slots:
   void addView();
@@ -76,6 +77,7 @@ private:
   uint highlightMode(const QString &name) const;
   void clearMarks(uint type);
   void init(bool withDebugger);
+  void updateBreakpointActions(const Breakpoint::Data*);
 };
 
 //-----------------------------------------------------------------------------
