@@ -76,6 +76,10 @@ MainWindow::MainWindow()
 : _configGenerator(NULL),
   _actionAfterBuild(Programmer::ProgramAction::Nb_Types)
 {
+  FOR_EACH(ExternalToolType, type) {
+    _externalToolProcesses[type.type()] = NULL;
+  }
+
 // status bar
     _actionStatus = new QLabel(statusBar());
     statusBar()->addWidget(_actionStatus);
@@ -186,26 +190,22 @@ MainWindow::MainWindow()
     a->setIcon(KIcon("window-close"));
     actionCollection()->addAction(KStandardAction::Quit, this, SLOT(close()));
 
-    // edit actions
-
-    // view actions
-    a = actionCollection()->addAction("history_back", Main::_editorManager, SLOT(goBack()));
+    // window actions
+    a = actionCollection()->addAction("window_history_back", Main::_editorManager, SLOT(goBack()));
     KGuiItem guiItem = KStandardGuiItem::back();
     a->setText(guiItem.text());
     a->setIcon(guiItem.icon());
-    a = actionCollection()->addAction("history_forward",  Main::_editorManager, SLOT(goForward()));
+    a = actionCollection()->addAction("window_history_forward",  Main::_editorManager, SLOT(goForward()));
     guiItem = KStandardGuiItem::forward();
     a->setText(guiItem.text());
     a->setIcon(guiItem.icon());
-    a = actionCollection()->addAction("view_switch_to", Main::_editorManager, SLOT(switchToEditor()));
+    a = actionCollection()->addAction("window_switch_to", Main::_editorManager, SLOT(switchToEditor()));
     a->setText(i18n("Switch to..."));
     a->setShortcut(Qt::CTRL + Qt::Key_Slash);
-    a = actionCollection()->addAction("view_switch_source", Main::_editorManager, SLOT(switchHeaderImplementation()));
+    a = actionCollection()->addAction("window_switch_source", Main::_editorManager, SLOT(switchHeaderImplementation()));
     a->setText(i18n("Switch Header/Implementation"));
     a->setShortcut(Qt::SHIFT + Qt::Key_F12);
-    actionCollection()->addAction("toggle_breakpoint", Debugger::manager, SLOT(toggleBreakpoint()));
-    actionCollection()->addAction("enable_breakpoint", Debugger::manager, SLOT(toggleEnableBreakpoint()));
-    a = actionCollection()->addAction("show_disassembly_location", Debugger::manager, SLOT(showDisassemblyLocation()));
+    a = actionCollection()->addAction("window_show_disassembly_location", Debugger::manager, SLOT(showDisassemblyLocation()));
     a->setText(i18n("Show disassembly location"));
 
     // project actions
@@ -353,6 +353,9 @@ MainWindow::MainWindow()
     a = actionCollection()->addAction("options_configure_programmers", this, SLOT(configureProgrammers()));
     a->setText(i18n("Configure Programmers..."));
     a->setIcon(KIcon("audio-card"));
+    a = actionCollection()->addAction("options_configure_editor", this, SLOT(configureEditor()));
+    a->setText(i18n("Configure Editor..."));
+    a->setIcon(KIcon("preferences-other"));
     actionCollection()->addAction(KStandardAction::Preferences, this, SLOT(configure()));
 
     setupGUI(ToolBar|Keys|StatusBar|Create);
@@ -420,6 +423,11 @@ void MainWindow::configureProgrammers()
   Debugger::manager->update(true);
 }
 
+void MainWindow::configureEditor()
+{
+  TextEditor::configure();
+}
+
 void MainWindow::selectProgrammer(const Programmer::Group &group)
 {
   if ( group.name()==Main::programmerGroup().name() ) return;
@@ -541,14 +549,18 @@ bool MainWindow::openFile()
   filter += "\n*|" + i18n("All Files");
   PURL::Url url = PURL::getOpenUrl("kfiledialog:///open_file", filter, this ,i18n("Open File"));
   if ( url.fileType()==PURL::Project || url.fileType()==PURL::PikdevProject ) {
-    stopOperations();
-    if ( !Main::_projectManager->openProject(url) ) return false;
-    updateGUI();
-    return true;
+    return openProject(url);
   }
   return Main::_editorManager->openFile(url);
 }
 
+bool MainWindow::openProject(const PURL::Url& url)
+{
+  stopOperations();
+  if ( !Main::_projectManager->openProject(url) ) return false;
+  updateGUI();
+  return true;
+}
 void MainWindow::updateGUI()
 {
   static bool updating = false;
@@ -581,10 +593,10 @@ void MainWindow::updateGUI()
   const PURL::FileType currentType = (Main::currentEditor() != NULL ? Main::currentEditor()->fileType() : PURL::Nb_FileTypes);
   const bool isSource = (currentType==PURL::Nb_FileTypes ? false : currentType.data().group==PURL::Source);
   const bool isHeader = (currentType==PURL::Nb_FileTypes ? false : currentType.data().group==PURL::Header);
-  Main::action("view_switch_source")->setEnabled(isSource || isHeader);
-  Main::action("history_back")->setEnabled(Main::editorManager().history().hasBack());
-  Main::action("history_forward")->setEnabled(Main::editorManager().history().hasForward());
-  Main::action("show_disassembly_location")->setEnabled(Debugger::manager->coff()!=0 && (isSource || isHeader));
+  Main::action("window_switch_source")->setEnabled(isSource || isHeader);
+  Main::action("window_history_back")->setEnabled(Main::editorManager().history().hasBack());
+  Main::action("window_history_forward")->setEnabled(Main::editorManager().history().hasForward());
+  Main::action("window_show_disassembly_location")->setEnabled(Debugger::manager->coff()!=0 && (isSource || isHeader));
 
 
   // update project
@@ -677,35 +689,58 @@ void MainWindow::runExternalTool()
   FOR_EACH(ExternalToolType, type) {
     QString name = "tools_" + type.key();
     if (sender() == actionCollection()->action(name.latin1())) {
-      if (_externalToolProcesses[type.type()].get() != NULL) return;
-      ::Process::StringOutput* process = new ::Process::StringOutput;
-      _externalToolProcesses[type.type()].reset(process);
-      QStringList args;
-      if (type == ExternalToolType::KFind) {
-        QString path;
-        PURL::Url url = Main::projectManager().projectUrl();
-        if ( !url.isEmpty() ) path = url.path();
-        args.append(path);
-      }
-      process->setup(type.key(), args, false);
-      connect(process, SIGNAL(done(int)), SLOT(externalToolDone()));
-      if (!process->start()) {
-        if (type.data().url != NULL) {
-          MessageBox::detailedSorry(i18n("Could not run \"%1\"").arg(type.key()), type.data().url, Log::Show);
-        } else {
-          MessageBox::sorry(i18n("Could not run \"%1\"").arg(type.key()), Log::Show);
-        }
-        _externalToolProcesses[type.type()].reset(NULL);
-      }
+      runExternalTool(type);
+      break;
     }
   }
 }
 
+void MainWindow::runKfind()
+{
+  runExternalTool(ExternalToolType::KFind);
+}
+
+void MainWindow::runExternalTool(ExternalToolType type)
+{
+  if (_externalToolProcesses[type.type()] != NULL) return;
+  ::Process::StringOutput* process = new ::Process::StringOutput;
+  _externalToolProcesses[type.type()] = process;
+  QStringList args;
+  if (type == ExternalToolType::KFind) {
+    QString path;
+    PURL::Url url = Main::projectManager().projectUrl();
+    if ( !url.isEmpty() ) path = url.path();
+    args.append(path);
+  }
+  process->setup(type.key(), args, false);
+  connect(process, SIGNAL(done()), SLOT(externalToolDone()));
+  connect(process, SIGNAL(error()), SLOT(externalToolError()));
+  process->start();
+}
+
 void MainWindow::externalToolDone()
 {
   FOR_EACH(ExternalToolType, type) {
-    if (sender() == _externalToolProcesses[type.type()].get()) {
-      _externalToolProcesses[type.type()].reset(NULL);
+    if (sender() == _externalToolProcesses[type.type()]) {
+      _externalToolProcesses[type.type()]->deleteLater();
+      _externalToolProcesses[type.type()] = NULL;
+      break;
+    }
+  }
+}
+
+void MainWindow::externalToolError()
+{
+  FOR_EACH(ExternalToolType, type) {
+    if (sender() == _externalToolProcesses[type.type()]) {
+      if (type.data().url != NULL) {
+        MessageBox::detailedSorry(i18n("Could not run \"%1\"").arg(type.key()), type.data().url, Log::Show);
+      } else {
+        MessageBox::sorry(i18n("Could not run \"%1\"").arg(type.key()), Log::Show);
+      }
+      _externalToolProcesses[type.type()]->deleteLater();
+      _externalToolProcesses[type.type()] = NULL;
+      break;
     }
   }
 }
