@@ -57,6 +57,9 @@ public slots:
   void selectTool(const Tool::Group &group);
   void selectProgrammer(const Programmer::Group &group);
 
+  bool openProject(const PURL::Url& url);
+  void closeProject();
+
 private slots:
   void newHexFile();
   bool openFile();
@@ -80,14 +83,16 @@ private slots:
 
   void configureToolchains();
   void configureProgrammers();
+  void configureEditor();
   void showProgrammerSettings() { configure(ConfigCenter::ProgOptions); }
   void showDebuggerSettings() { configure(ConfigCenter::DebugOptions); }
 
   void runExternalTool();
   void externalToolDone();
+  void externalToolError();
+  void runKfind();
 
   void openRecentProject(const KUrl &url);
-  void closeProject();
 
   void initialLoading();
 
@@ -102,7 +107,7 @@ private:
   VoltageStatusWidget    *_vddStatus, *_vppStatus;
   Q3ProgressBar          *_actionProgress;
   ConfigGenerator        *_configGenerator;
-  std::auto_ptr< ::Process::Base> _externalToolProcesses[ExternalToolType::Nb_Types];
+  ::Process::Base*        _externalToolProcesses[ExternalToolType::Nb_Types];
   Programmer::ProgramAction _actionAfterBuild;
   std::auto_ptr<BusyCursorStarter> _busyCursor;
 
@@ -132,6 +137,7 @@ private:
   void cleanBuild(bool singleFile);
   virtual void keyPressEvent(QKeyEvent *e);
   void doAfterBuild();
+  void runExternalTool(ExternalToolType);
 };
 
 #endif
