@@ -22,13 +22,14 @@ void VoltageStatusWidget::setVoltage(const Device::VoltageValue &v)
 }
 
 //----------------------------------------------------------------------------
-ViewMenuAction::ViewMenuAction(KDockWidget *widget)
-  : KToggleAction(widget->tabPageLabel()), _widget(widget)
-{}
+ViewMenuAction::ViewMenuAction(K3DockWidget *widget)
+  : KToggleAction(widget->tabPageLabel(), widget), _widget(widget)
+{
+  connect(this, SIGNAL(triggered()), SLOT(slotActivated()));
+}
 
 void ViewMenuAction::slotActivated()
 {
-  KAction::slotActivated();
   emit activated(_widget);
 }
 
@@ -38,13 +39,8 @@ MenuBarButton::MenuBarButton(const QString &icon, QWidget *parent)
 {
   QFontMetrics fm(font());
   int h = fm.height();
-#ifdef NO_KDE
-  setIconSet(IconLoader::loadIcon(icon, IconLoader::Small));
-#else
-  h += 2*style().pixelMetric(QStyle::PM_DefaultFrameWidth, this);
-  KIconLoader loader;
-  setIconSet(loader.loadIcon(icon, KIcon::Small, fm.height()-2));
-#endif
+  //h += 2*style().pixelMetric(QStyle::PM_DefaultFrameWidth, this);
+  setIconSet(KIcon(icon));
   setFixedHeight(h);
   setUsesTextLabel(false);
   setAutoRaise(true);
