@@ -86,10 +86,10 @@ Register::WatchedListView::WatchedListView(QWidget *parent)
   _root->setOpen(true);
 }
 
-KPopupMenu *Register::WatchedListView::appendFormatMenu(KPopupMenu *parent, uint offset)
+KMenu* Register::WatchedListView::appendFormatMenu(KMenu* parent, uint offset)
 {
   QPixmap icon = IconLoader::loadIcon("fonts", IconLoader::Small);
-  KPopupMenu *popup = new KPopupMenu;
+  KMenu* popup = new KMenu;
   popup->addTitle(i18n("Format"));
   FOR_EACH(NumberBase, base) popup->insertItem(base.label(), offset + base.type());
   parent->insertItem(icon, i18n("Format"), popup);
@@ -169,9 +169,9 @@ void Register::WatchedListView::contextMenu(Q3ListViewItem *item, const QPoint &
   } else {
     if ( item->rtti()==Register::PortBitRtti ) return;
     Register::ListViewItem *ritem = static_cast<ListViewItem *>(item);
-    std::auto_ptr<KPopupMenu> pop(new KPopupMenu);
+    std::auto_ptr<KMenu> pop(new KMenu);
     pop->addTitle(ritem->label());
-    KPopupMenu *fpop = appendFormatMenu(pop.get(), 0);
+    KMenu* fpop = appendFormatMenu(pop.get(), 0);
     FOR_EACH(NumberBase, base) fpop->setItemChecked(base.type(), ritem->base()==base);
     pop->insertSeparator();
     QPixmap icon = IconLoader::loadIcon("edit-rename", IconLoader::Small);
