@@ -107,7 +107,7 @@ CLI::ExitCode CLI::Main::prepareCommand(const CommandProperties& properties)
 
 CLI::ExitCode CLI::Main::executeCommand(const QString &command)
 {
-  if (_device != NULL) _memory.reset(_device->group().createMemory(*_device));
+  if (_device != NULL) _memory = _device->group().createMemory(*_device);
 
   if ( command=="check" ) {
     if (_device == NULL) return okExit(i18n("Hex file is valid."));
@@ -182,7 +182,7 @@ CLI::ExitCode CLI::Main::executeCommand(const QString &command)
   }
   if ( command=="checksum" ) {
     QStringList warnings;
-    Device::Memory::WarningTypes wtypes = _memory->fromHexBuffer(_source1, warnings);
+    _memory->fromHexBuffer(_source1, warnings);
     for (uint i=0; i<uint(warnings.count()); i++) log(Log::LineType::Warning, warnings[i]);
     log(Log::LineType::Warning, i18n("Checksum computation is experimental and is not always correct!")); // #### REMOVE ME
     BitValue cs = _memory->checksum();
@@ -201,7 +201,7 @@ CLI::ExitCode CLI::Main::executeCommand(const QString &command)
     } else {
       bool ok;
       uint value = fromAnyLabel(_fill, &ok);
-      Q_ASSERT(ok);
+      ASSERT(ok);
       _memory->fill(value);
     }
     PURL::File dest(output(), view());
@@ -210,7 +210,7 @@ CLI::ExitCode CLI::Main::executeCommand(const QString &command)
     if ( !dest.close() ) return FILE_ERROR;
     return okExit(i18n("File created."));
   }
-  Q_ASSERT(false);
+  ASSERT(false);
   return ARG_ERROR;
 }
 
