@@ -54,9 +54,9 @@ Programmer::Generic *Programmer::CliManager::createProgrammer(const Device::Data
   if (!CLI::_firmwareDir.isEmpty()
       && !(_programmer->group().properties() & ::Programmer::Custom)) {
     typedef ::Programmer::Base Base; // for G++ 3.3.6
-    static_cast<Base*>(_programmer)->setFirmwareDirectory(CLI::_firmwareDir.path());
+    static_cast<Base*>(_programmer.get())->setFirmwareDirectory(CLI::_firmwareDir.path());
   }
-  return _programmer;
+  return _programmer.get();
 }
 
 bool Programmer::CliManager::internalInitProgramming(ProgramAction action)
