@@ -9,12 +9,6 @@
 #include "cmdline.h"
 #include "cmdline.moc"
 
-#if defined(HAVE_READLINE)
-#  include <readline/readline.h>
-#  include <readline/history.h>
-#else
-#  include <stdio.h>
-#endif
 #include <signal.h>
 #include <memory>
 
@@ -196,7 +190,7 @@ CLI::ExitCode CLI::Main::prepareCommand(const CommandProperties& properties)
 
   if ( (properties & NeedInput) || (properties & NeedOutput) ) {
     _memory.reset(NULL);
-    if (properties & NeedDevice) _memory.reset(_device->group().createMemory(*_device));
+    if (properties & NeedDevice) _memory = _device->group().createMemory(*_device);
   }
 
   if (properties & NeedInput) {
@@ -633,13 +627,9 @@ CLI::ExitCode CLI::Main::executeRawCommands(const QString &filename)
   }
   for (;;) {
     QString s;
-#if QT_VERSION<0x040000
-    if ( file.readLine(s, 1000)==-1 ) break;
-#else
     char buffer[1000];
     if ( file.readLine(buffer, 1000)==-1 ) break;
     s += buffer;
-#endif
     bool write = !s.startsWith(" ");
     s = s.stripWhiteSpace();
     if ( s.isEmpty() ) continue;
