@@ -17,14 +17,13 @@
 class ChecksumCheck : public DeviceTest
 {
 public:
-  ChecksumCheck() : _memory(0) {}
   virtual bool skip(const Device::Data &data) const;
   virtual bool init(const Device::Data &data);
   virtual bool executeDevice(const Device::Data &data);
   virtual void cleanup(const Device::Data &data);
 
 private:
-  Pic::Memory *_memory;
+  std::auto_ptr<Device::Memory> _memory;
 
   void setProtection(const Pic::Data &data, const Pic::Checksum::Data &cdata,
                      const QString &maskName, const QString &valueName);
