@@ -121,7 +121,7 @@ bool Programmer::Base::connectHardware()
     if ( !checkFirmwareVersion() ) return false;
     if ( !setTargetPowerOn(false) ) return false;
     if ( !setTarget() ) return false;
-    log(Log::LineType::Information, i18n("  Set target self powered: %1").arg(_targetSelfPowered ? "true" : "false"));
+    log(Log::LineType::Information, i18n("  Set target power: %1").arg(!_targetSelfPowered ? "true" : "false"));
     if ( !setTargetPowerOn(!_targetSelfPowered) ) return false;
     if ( !internalSetupHardware() ) return false;
     if ( !readVoltages() ) return false;
@@ -158,9 +158,13 @@ void Programmer::Base::disconnectHardware()
 
 PURL::Directory Programmer::Base::firmwareDirectory()
 {
-  if ( _firmwareDirectory.isEmpty() ) _firmwareDirectory = GroupConfig::firmwareDirectory(group());
-  if ( !_firmwareDirectory.exists() ) {
-    log(Log::LineType::Error, i18n("Firmware directory is not configured or does not exist."));
+  if (_firmwareDirectory.isEmpty()) _firmwareDirectory = GroupConfig::firmwareDirectory(group());
+  if (_firmwareDirectory.isEmpty()) {
+    log(Log::LineType::Error, i18n("Firmware directory is not configured."));
+    return PURL::Directory();
+  }
+  if (!_firmwareDirectory.exists()) {
+    log(Log::LineType::Error, i18n("Firmware directory '%1' does not exist.").arg(_firmwareDirectory.pretty()));
     return PURL::Directory();
   }
   return _firmwareDirectory;
@@ -238,7 +242,7 @@ void Programmer::Base::log(Log::DebugLevel level, const QString &message, Log::A
 bool Programmer::Base::setTargetPowerOn(bool on)
 {
   _targetPowerOn = on;
-  return _deviceSpecific->setTargetPowerOn(on);
+  return _deviceSpecific.get() != NULL ? _deviceSpecific->setTargetPowerOn(on) : true;
 }
 
 void Programmer::Base::appendTask(Task task, const Device::MemoryRange& range)
