@@ -89,7 +89,7 @@ void Direct::Hardware::setPin(PinType type, bool on)
 bool Direct::Hardware::readBit()
 {
   int pin = _data.pins[DataIn];
-  Q_ASSERT( pin!=0 );
+  ASSERT( pin!=0 );
   uint p = (pin<0 ? -pin : pin)-1;
   bool on;
   _port->readPin(p, (pin<0 ? Port::NegativeLogic : Port::PositiveLogic), on);
@@ -117,7 +117,7 @@ Port::IODir Direct::Hardware::ioTypeForPin(int pin) const
 
 uint Direct::Hardware::pinForIndex(Port::IODir dir, uint i) const
 {
-  Q_ASSERT( i<=uint(_port->pinData(dir).size()) );
+  ASSERT( i<=uint(_port->pinData(dir).size()) );
   if ( i==uint(_port->pinData(dir).size()) ) return _port->groundPin()+1;
   return _port->pinData(dir)[i].pin+1;
 }
@@ -125,17 +125,17 @@ uint Direct::Hardware::pinForIndex(Port::IODir dir, uint i) const
 uint Direct::Hardware::indexForPin(Port::IODir dir, int pin) const
 {
   QValueVector<Port::PinData> v = _port->pinData(dir);
-  Q_ASSERT( pin!=0 );
+  ASSERT( pin!=0 );
   uint p = (pin<0 ? -pin : pin)-1;
   for (uint i=0; i<uint(v.count()); i++)
     if ( v[i].pin==p ) return i;
-  Q_ASSERT( isGroundPin(pin) );
+  ASSERT( isGroundPin(pin) );
   return v.count();
 }
 
 bool Direct::Hardware::isGroundPin(int pin) const
 {
-  Q_ASSERT( pin!=0 );
+  ASSERT( pin!=0 );
   uint p = (pin<0 ? -pin : pin)-1;
   return _port->isGroundPin(p);
 }
