@@ -34,7 +34,7 @@ void Programmer::ConfigWidget::loadConfig()
 
 void Programmer::ConfigWidget::saveConfig()
 {
-  if (_firmwareDir) GroupConfig::writeFirmwareDirectory(_group, _firmwareDir->url().url());
+  if (_firmwareDir) GroupConfig::writeFirmwareDirectory(_group, _firmwareDir->url().path());
 }
 
 bool Programmer::ConfigWidget::setPort(const HardwareDescription &)
