@@ -36,7 +36,7 @@ protected:
   const Group &_group;
 
 private:
-  KURLRequester *_firmwareDir;
+  KUrlRequester *_firmwareDir;
 };
 
 } // namespace
