@@ -274,6 +274,13 @@ bool Icd2::Hardware::getDebugExecVersion(VersionData &version)
 
 bool Icd2::Hardware::setTargetPowerOn(bool on)
 {
+  if (on) {
+    const double vdd = device().architecture().data().nominalVdd;
+    if (vdd != 5.0) {
+      log(Log::LineType::Warning, i18n("Set target power disabled because device does not support 5V supply (nomial vdd is %1V).").arg(vdd));
+      return true;
+    }
+  }
   return command(QString("05") + (on ? "FF" : "00"), 0);
 }
 
