@@ -20,10 +20,10 @@ class ProgrammerBase : public ::Programmer::PicBase
 public:
   ProgrammerBase(const Programmer::Group &group, const Pic::Data *data, const char *name)
     : ::Programmer::PicBase(group, data, name) {}
+  Hardware *hardware() const { return static_cast<Hardware *>(_hardware.get()); }
   virtual bool readFirmwareVersion();
 
 protected:
-  Hardware &hardware() { return static_cast<Hardware &>(*_hardware); }
   virtual bool doUploadFirmware(PURL::File &file);
 };
 
