@@ -20,29 +20,22 @@
 Programmer::Manager *Programmer::manager = 0;
 
 Programmer::Manager::Manager(QObject *parent)
-  : QObject(parent, "programmer_manager"), _programmer(0)
+: QObject(parent, "programmer_manager"),
+  _halting(false)
 {}
 
-Programmer::Manager::~Manager()
-{
-  delete _programmer;
-  _programmer = NULL;
-}
-
 void Programmer::Manager::clear()
 {
-  delete _programmer;
-  _programmer = NULL;
+  _programmer.reset(NULL);
 }
 
 void Programmer::Manager::internalCreateProgrammer(const Device::Data *data, const HardwareDescription &hd)
 {
-  if (_programmer != NULL
+  if (_programmer.get() != NULL
       && &_programmer->group() == group()
       && _programmer->device() == data
       && !hasError()) return;
-  delete _programmer;
-  _programmer = group()->createProgrammer(isTargetSelfPowered(), data, hd, this);
+  _programmer.reset(group()->createProgrammer(isTargetSelfPowered(), data, hd, this));
   connect(&_programmer->progressMonitor(), SIGNAL(setLabel(const QString &)), SIGNAL(actionMessage(const QString &)));
   connect(&_programmer->progressMonitor(), SIGNAL(setTotalProgress(uint)), SIGNAL(setTotalProgress(uint)));
   connect(&_programmer->progressMonitor(), SIGNAL(setProgress(uint)), SIGNAL(setProgress(uint)));
@@ -160,8 +153,7 @@ bool Programmer::Manager::disconnectDevice()
   _programmer->setTargetPowerOn(false);
   _programmer->disconnectHardware();
   endProgramming();
-  delete _programmer;
-  _programmer = NULL;
+  _programmer.reset(NULL);
   if (debugger) log(Log::LineType::Information, i18n("Stopped."));
   return true;
 }
@@ -176,8 +168,11 @@ bool Programmer::Manager::run()
 
 bool Programmer::Manager::halt()
 {
-  if ( !initProgramming(ProgramAction::Halt) ) return false;
-  bool ok;
+  if (_halting) return true;
+  _halting = true;
+  bool ok = initProgramming(ProgramAction::Halt);
+  _halting = false;
+  if (!ok) return false;
   if (group()->isDebugger()) {
     ok = ::Debugger::manager->halt();
     setState(Idle);
@@ -191,7 +186,7 @@ bool Programmer::Manager::halt()
 
 void Programmer::Manager::stop()
 {
-  if (_programmer) _programmer->disconnectHardware();
+  if (_programmer.get() != NULL) _programmer->disconnectHardware();
 }
 
 bool Programmer::Manager::restart()
