@@ -12,7 +12,7 @@
 #include "common/port/port.h"
 
 //-----------------------------------------------------------------------------
-void Pickit2::USBPort::fillCommand(Pickit::Array &cmd, uchar command, uint nbBytes,
+void Pickit2::USBPort::fillCommand(ByteArray &cmd, uchar command, uint nbBytes,
                                    uint address, uint i, bool longAddress) const
 {
   cmd[i] = command;
@@ -22,9 +22,9 @@ void Pickit2::USBPort::fillCommand(Pickit::Array &cmd, uchar command, uint nbByt
   if (longAddress) cmd[i+4] = (address >> 16) & 0xFF;
 }
 
-Pickit::Array Pickit2::USBPort::createCommand(uchar c, uint nbBytes, uint address, bool longAddress) const
+ByteArray Pickit2::USBPort::createCommand(uchar c, uint nbBytes, uint address, bool longAddress) const
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   fillCommand(cmd, c, nbBytes, address, 0, longAddress);
   return cmd;
 }
@@ -40,7 +40,7 @@ bool Pickit2::USBPort::readFirmwareCodeMemory(Device::Array &data, const Device:
     uint end = 15;
     for (; end>start; end--) if ( data[i + end].isInitialized() ) break;
     uint nb = end - start + 1;
-    Pickit::Array cmd = createCommand(1, 2*nb, 2*i);
+    ByteArray cmd = createCommand(1, 2*nb, 2*i);
     if ( !command(cmd) ) return false;
     QValueVector<uint> read;
     if ( !receiveWords(1, 1, read) ) return false;
@@ -63,7 +63,7 @@ bool Pickit2::USBPort::readFirmwareCodeMemory(Device::Array &data, const Device:
 bool Pickit2::USBPort::eraseFirmwareCodeMemory()
 {
   log(Log::DebugLevel::Normal, "  Erase pickit2 firmware");
-  Pickit::Array cmd = createCommand(3, 0xC0, 0x2000);
+  ByteArray cmd = createCommand(3, 0xC0, 0x2000);
   if ( !command(cmd) ) return false; // erase 0x2000-0x4FFF
   Port::usleep(1000000);
   cmd = createCommand(3, 0xC0, 0x5000);
@@ -82,7 +82,7 @@ bool Pickit2::USBPort::writeFirmwareCodeMemory(const Device::Array &data, Progre
     uint end = 15;
     for (; end>start; end--) if ( data[i + end].isInitialized() ) break;
     uint nb = end - start + 1;
-    Pickit::Array cmd = createCommand(2, 2*nb, 2*i);
+    ByteArray cmd = createCommand(2, 2*nb, 2*i);
     for (uint k=0; k<nb; k++) {
       cmd[5 + 2*k] = data[i + start + k].byte(0);
       cmd[6 + 2*k] = data[i + start + k].byte(1);
@@ -94,7 +94,7 @@ bool Pickit2::USBPort::writeFirmwareCodeMemory(const Device::Array &data, Progre
   Device::Array read;
   if ( !readFirmwareCodeMemory(read, &data, monitor) ) return false;
   log(Log::DebugLevel::Normal, "  Write pickit2 firmware-loaded key");
-  Pickit::Array cmd = createCommand(2, 2, 0x7FFE);
+  ByteArray cmd = createCommand(2, 2, 0x7FFE);
   cmd[5] = 0x55;
   cmd[6] = 0x55;
   return command(cmd);
@@ -116,7 +116,7 @@ bool Pickit2::Hardware::readVoltages(Device::VoltageValues &voltages)
     return true;
   }
   if ( !port().command('M') ) return false;
-  Array a;
+  ByteArray a = createArray();
   if ( !port().receive(a) ) return false;
   voltages[Device::VoltageType::TargetVdd] = Device::VoltageValue(a[0] & 0x08 ? Device::VoltageValue::Error : Device::VoltageValue::Normal, double(a[1] + a[2]*256) * 5.0 / 65535);
   voltages[Device::VoltageType::TargetVpp] = Device::VoltageValue(a[0] & 0x10 ? Device::VoltageValue::Error : Device::VoltageValue::Normal, double(a[3] + a[4]*256) * (5.0 /65535) * (7.4 / 2.7));
@@ -128,7 +128,7 @@ bool Pickit2::Hardware::setVddVpp(double vdd, double vpp)
   log(Log::DebugLevel::Extra, QString("setVddVpp: Firmware is %1").arg(_base.firmwareVersion().pretty()));
   if ( _base.firmwareVersion()<VersionData(1, 20, 0) ) return true;
   log(Log::DebugLevel::Normal, QString("  set Vdd = %1 V and Vpp = %2 V").arg(vdd).arg(vpp));
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 's';
   uint cvdd = uint(32.0 * vdd + 12.5);
   cvdd <<= 6;
@@ -153,7 +153,7 @@ bool Pickit2::Hardware::setVddVpp(double vdd, double vpp)
 //-----------------------------------------------------------------------------
 bool Pickit2::Baseline::init()
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 'c';
   cmd[1] = 0x00;   // Load Configuration
   cmd[2] = 0x02;   // Load Program latches
@@ -176,7 +176,7 @@ bool Pickit2::Baseline::init()
 //-----------------------------------------------------------------------------
 bool Pickit2::P16F::init()
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 'c';
   cmd[1] = 0x00;   // Load Configuration
   cmd[2] = 0x02;   // Load Program latches
@@ -199,7 +199,7 @@ bool Pickit2::P16F::init()
 //-----------------------------------------------------------------------------
 bool Pickit2::P16F87XA::init()
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 'c';
   cmd[1] = 0x00;   // Load Configuration
   cmd[2] = 0x02;   // Load Program latches
@@ -222,7 +222,7 @@ bool Pickit2::P16F87XA::init()
 //-----------------------------------------------------------------------------
 bool Pickit2::P16F7X::init()
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 'c';
   cmd[1] = 0x00;   // Load Configuration
   cmd[2] = 0x02;   // Load Program latches
@@ -244,7 +244,7 @@ bool Pickit2::P16F7X::init()
 
 bool Pickit2::P16F716::init()
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 'c';
   cmd[1] = 0x00;   // Load Configuration
   cmd[2] = 0x02;   // Load Program latches
@@ -267,7 +267,7 @@ bool Pickit2::P16F716::init()
 //-----------------------------------------------------------------------------
 bool Pickit2::P18F::init()
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 'c';
   cmd[1] = 0x00;   // Load Configuration
   cmd[2] = 0x02;   // Load Program latches
@@ -289,7 +289,7 @@ bool Pickit2::P18F::init()
 
 bool Pickit2::P18F::doEraseCommand(uint cmd1, uint cmd2)
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 0x85;
   cmd[1] = cmd1;
   cmd[2] = cmd2;
@@ -316,7 +316,7 @@ bool Pickit2::P18F::doRead(Pic::MemoryRangeType type, uint wordOffset, Device::A
     case Pic::MemoryRangeType::DeviceId:
     case Pic::MemoryRangeType::UserId:
     case Pic::MemoryRangeType::Config: {
-      Pickit::Array cmd = port.createCommand(0x80, data.count(), device().range(type).start.toUInt());
+      ByteArray cmd = port.createCommand(0x80, data.count(), device().range(type).start.toUInt());
       if ( !port.command(cmd) ) return false;
       if ( !hardware().port().receiveWords(1, 1, words) ) return false;
       for (uint k=0; k<data.count(); k++) {
@@ -327,7 +327,7 @@ bool Pickit2::P18F::doRead(Pic::MemoryRangeType type, uint wordOffset, Device::A
     }
     case Pic::MemoryRangeType::Code:
       for (uint i=0; i<data.count();) {
-        Array cmd;
+        ByteArray cmd = createArray();
         for (uint k=0; k<8; k++) port.fillCommand(cmd, 0x80, 64, 2*(i + 32 * k), 5*k);
         if ( !port.command(cmd) ) return false;
         for (uint k=0; k<8; k++) {
@@ -343,7 +343,7 @@ bool Pickit2::P18F::doRead(Pic::MemoryRangeType type, uint wordOffset, Device::A
       return true;
     case Pic::MemoryRangeType::Eeprom:
       for (uint i=0; i<data.count();) {
-       Pickit::Array cmd = port.createCommand(0x81, 64, i, false);
+       ByteArray cmd = port.createCommand(0x81, 64, i, false);
         if ( !port.command(cmd) ) return false;
         if ( !hardware().port().receiveWords(1, 1, words) ) return false;
         for (uint k=0; k<64; k++) {
@@ -373,12 +373,12 @@ bool Pickit2::P18F::doWrite(Pic::MemoryRangeType type, uint wordOffset, const De
   USBPort &port = static_cast<USBPort &>(hardware().port());
   switch (type.type()) {
     case Pic::MemoryRangeType::UserId: {
-      Pickit::Array cmd = port.createCommand(0x82, data.count()/2, device().range(type).start.toUInt());
+      ByteArray cmd = port.createCommand(0x82, data.count()/2, device().range(type).start.toUInt());
       for (uint i=0; i<data.count(); i++) cmd[i + 5] = data[i].byte(0);
       return port.command(cmd);
     }
     case Pic::MemoryRangeType::Config: {
-      Array cmd;
+      ByteArray cmd = createArray();
       for (uint i=0; i<data.count()/2; i++) {
         cmd[4*i]     = 0x84;
         cmd[1 + 4*i] = 2*i;
@@ -391,7 +391,7 @@ bool Pickit2::P18F::doWrite(Pic::MemoryRangeType type, uint wordOffset, const De
       uint nb = Pickit2::data(device().name()).progWidth;
       for (uint i=0; i<data.count();) {
         bool allBlank = true;
-        Pickit::Array cmd = port.createCommand(0x82, nb, 2*i);
+        ByteArray cmd = port.createCommand(0x82, nb, 2*i);
         for (uint k=0; k<nb; k++) {
           if ( data[i].byte(0)!=0xFF || data[i].byte(1)!=0xFF ) allBlank = false;
           cmd[5 + 2*k] = data[i].byte(0);
@@ -406,7 +406,7 @@ bool Pickit2::P18F::doWrite(Pic::MemoryRangeType type, uint wordOffset, const De
     case Pic::MemoryRangeType::Eeprom:
       for (uint i=0; i<data.count();) {
         bool allBlank = true;
-        Pickit::Array cmd = port.createCommand(0x87, 32, i, false);
+        ByteArray cmd = port.createCommand(0x87, 32, i, false);
         for (uint k=0; k<32; k++) {
           if ( data[i].byte(0)!=0xFF ) allBlank = false;
           cmd[4+k] = data[i].byte(0);
@@ -430,7 +430,7 @@ bool Pickit2::P18F::doWrite(Pic::MemoryRangeType type, uint wordOffset, const De
 
 bool Pickit2::P18F2X20::doEraseCommand(uint cmd1)
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = 0x86;
   cmd[1] = cmd1;
   return hardware().port().command(cmd);
