@@ -29,20 +29,8 @@ void Pickit::AdvancedDialog::regenerateCalibration()
     MessageBox::sorry(i18n("Osccal regeneration not available for the selected device."), Log::Show);
     return;
   }
-#ifdef NO_KDE
-  QString filename = QFileDialog::getOpenFileName(this, i18n("Open Calibration Firmware"), QString::null,
-                                                  PURL::filter(PURL::Hex));
-  PURL::Url url = KURL::fromPathOrURL(filename);
-#else
-  KFileDialog dialog(":open_autohex", PURL::filter(PURL::Hex), this, "autohex_dialog", true);
-  dialog.setOperationMode(KFileDialog::Opening);
-  dialog.setCaption(i18n("Open Calibration Firmware"));
-  dialog.setMode(KFile::File);
-  //dialog.ops->clearHistory();
-  dialog.setSelection("autocal.hex");
-  dialog.exec();
-  PURL::Url url(dialog.selectedURL());
-#endif
+  QString filename = KFileDialog::getOpenFileName(KUrl(), PURL::filter(PURL::Hex), this, i18n("Open Calibration Firmware"));
+  PURL::Url url = KUrl(filename);
   if ( url.isEmpty() ) return;
   base().regenerateOsccal(url);
 }
