@@ -59,7 +59,7 @@ bool Pickit2V2::Hardware::setTarget()
 bool Pickit2V2::Hardware::readStatus(ushort &status)
 {
   if ( !port().command(ReadStatus) ) return false;
-  Array a;
+  ByteArray a = createArray();
   if ( !port().receive(a) ) return false;
   status = (a[1] << 8) + a[0];
   return true;
@@ -67,7 +67,7 @@ bool Pickit2V2::Hardware::readStatus(ushort &status)
 
 bool Pickit2V2::Hardware::sendScript(const ushort *script, uint length)
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = ClearUploadBuffer;
   cmd[1] = ExecuteScript;
   cmd[2] = length;
@@ -86,7 +86,7 @@ bool Pickit2V2::Hardware::executeScript(uint i)
 bool Pickit2V2::Hardware::getScriptBufferChecksum(uint &checksum)
 {
   if ( !port().command(ScriptBufferChecksum) ) return false;
-  Array array;
+  ByteArray array = createArray();
   if ( !port().receive(array) ) return false;
   checksum = (array[0] << 24) + (array[1] << 16) + (array[2] << 8) + array[3];
   log(Log::DebugLevel::Extra, QString("get script buffer checksum: %1").arg(toHexLabel(checksum, 8)));
@@ -99,7 +99,7 @@ bool Pickit2V2::Hardware::downloadScript(ScriptType type, uint i)
   const ScriptData &sdata = SCRIPT_DATA[i-1];
   log(Log::DebugLevel::Max, QString("  download script #%1 (\"%2\") at position #%3")
                             .arg(i-1).arg(sdata.name).arg(toHexLabel(type, 2)));
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = DownloadScript;
   cmd[1] = type;
   cmd[2] = sdata.length;
@@ -162,7 +162,7 @@ bool Pickit2V2::Hardware::setVddVoltage(double value, double threshold)
   ushort v = ushort(qRound(32.0*value + 10.5)) << 6;
   uchar vfault = uchar(qRound(256.0 * (threshold * value) / 5.0));
   if ( vfault>210 ) vfault = 210;
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = SetVdd;
   cmd[1] = v & 0xFF;
   cmd[2] = v >> 8;
@@ -172,7 +172,7 @@ bool Pickit2V2::Hardware::setVddVoltage(double value, double threshold)
 
 bool Pickit2V2::Hardware::setVppVoltage(double value, double threshold)
 {
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = SetVpp;
   cmd[1] = 0x40;
   cmd[2] = uchar(qRound(18.61*value));
@@ -201,7 +201,7 @@ bool Pickit2V2::Hardware::setIcspSpeed(uchar speed)
 bool Pickit2V2::Hardware::getMode(VersionData &version, ::Programmer::Mode &mode)
 {
   if ( !port().command(FirmwareVersion) ) return false;
-  Array data;
+  ByteArray data = createArray();
   if ( !port().receive(data) ) return false;
   if ( data[0]=='B' ) {
     mode = ::Programmer::BootloadMode;
@@ -216,7 +216,7 @@ bool Pickit2V2::Hardware::getMode(VersionData &version, ::Programmer::Mode &mode
 bool Pickit2V2::Hardware::readVoltages(Device::VoltageValues &voltages)
 {
   if ( !port().command(ReadVoltages) ) return false;
-  Array array;
+  ByteArray array = createArray();
   if ( !port().receive(array) ) return false;
   double vadc = 256 * array[1] + array[0];
   voltages[Device::VoltageType::TargetVdd] = Device::VoltageValue(Device::VoltageValue::Normal, 5.0 * (vadc / 65536));
@@ -228,7 +228,7 @@ bool Pickit2V2::Hardware::readVoltages(Device::VoltageValues &voltages)
 bool Pickit2V2::Hardware::downloadAddress(Address address)
 {
   log(Log::DebugLevel::Max, QString("download address %1").arg(toHexLabel(address, 6)));
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = ClearDownloadBuffer;
   cmd[1] = DownloadData;
   cmd[2] = 3;
@@ -247,12 +247,12 @@ bool Pickit2V2::Hardware::runScript(ScriptType stype, uint repetitions, uint nbN
   for (uint i=0; i<repetitions; i++)
     if ( !executeScript(d.scriptIndexes[stype]) ) return false;
   if (nbNoLens) {
-    Array cmd;
+    ByteArray cmd = createArray();
     for (uint i=0; i<nbNoLens; i++) cmd[i] = UploadDataNoLen;
     if ( !port().command(cmd) ) return false;
   }
 #else
-  Array cmd;
+  ByteArray cmd = createArray();
   cmd[0] = ClearUploadBuffer;
   cmd[1] = RunScript;
   cmd[2] = stype;
@@ -389,7 +389,7 @@ bool Pickit2V2::Hardware::eraseRange(Pic::MemoryRangeType type)
 bool Pickit2V2::Hardware::downloadData(const QValueVector<uint> &data, uint &index, bool clearBuffer)
 {
   ASSERT( index<(uint)data.count() );
-  Array cmd;
+  ByteArray cmd = createArray();
   uint i = 0;
   if (clearBuffer) { cmd[i] = ClearDownloadBuffer; i++; }
   cmd[i] = DownloadData; i++;
