@@ -73,12 +73,12 @@ void CCSC::CompileFile::parseLine(const QString &line)
     doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
     return;
   }
-  if ( parseErrorLine(line, Compile::ParseErrorData("[*>-]+\\s\\w+\\s\\d+\\s\"([^\"]*)\"\\sLine\\s(\\d+)\\([^)]*\\):(.*)", 1, 2, 3, type)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("[*>-]+\\s\"([^\"]*)\"\\sLine\\s(\\d+):\\s\\w+\\s#\\d+:(.*)", 1, 2, 3, type)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("[*>-]+\\s\\w+\\s\\d+\\s\"([^\"]*)\"\\sLine\\s(\\d+)\\([^)]*\\):(.*)", 1, 2, 3, -1, type)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("[*>-]+\\s\"([^\"]*)\"\\sLine\\s(\\d+):\\s\\w+\\s#\\d+:(.*)", 1, 2, 3, -1, type)) ) return;
   doLog(type, line, QString::null, 0);
 }
 
-void CCSC::CompileFile::done(int code)
+void CCSC::CompileFile::done()
 {
   // with wine, rely on error file
   if ( Compile::Config::executableType(group())==Tool::ExecutableType::Windows ) {
@@ -91,7 +91,7 @@ void CCSC::CompileFile::done(int code)
       for (int i=0; i<lines.count(); i++) parseLine(lines[i]);
     }
   }
-  Compile::Process::done(code);
+  Compile::Process::done();
 }
 
 PURL::Url CCSC::CompileFile::url(PURL::FileType type, uint i) const
