@@ -24,8 +24,8 @@ QString GPUtils::Process::deviceName() const
 //-----------------------------------------------------------------------------
 void GPUtils::AssembleFile::logLine(::Process::OutputType, const QString &line)
 {
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(.+)\\[[0-9]+\\](.+)", 1, 2, 4, 3)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([^:]+):([0-9]+):(.+)", 2, 3, 4, Log::LineType::Warning)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(.+)\\[[0-9]+\\](.+)", 1, 2, 4, 3, Log::LineType::Error)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([^:]+):([0-9]+):(.+)", 2, 3, 4, -1, Log::LineType::Warning)) ) return;
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
