@@ -64,7 +64,7 @@ void ToolConfigWidget::init(Tool::Category category, const Tool::Group &group)
   _config = _group->createConfig(_project);
   _tmpProject = new Project(PURL::Url());
   _tmpConfig = _group->createConfig(*_tmpProject);
-  Compile::Data data(_category, QValueList<Compile::Item>(), QString::null, _project, Compile::NormalLinking, Compile::Build);
+  Compile::Data data(_category, QValueList<Compile::Item>(), _config->device(&_project).name(), _project, Compile::NormalLinking, Compile::Build);
   _process = _group->createCompileProcess(data, 0);
 
   initEntries();
