@@ -26,16 +26,14 @@ public slots:
   virtual void slotApply();
   virtual void slotUser1();
   virtual void slotUser2();
+  virtual void slotUser3();
 
 private slots:
-  void aboutToShowPageSlot(QWidget *page);
-  void showInformationDialog();
+  void currentPageChangedSlot(KPageWidgetItem*);
 
 private:
-  KPushButton *_infoButton;
-  QMap<QWidget *, ToolchainConfigWidget *> _pages;
-
-  ToolchainConfigWidget *current() const;
+  typedef std::vector<ToolchainConfigWidget*> ConfigWidgetVector;
+  ConfigWidgetVector _configWidgets;
 };
 
 #endif
