@@ -215,14 +215,18 @@ void ToolchainConfigWidget::detect()
     if ( !_group.base(k)->checkExecutable() ) _data[k].label->setText(i18n("Unknown"));
     else {
       _data[k].checkLines.clear();
-      delete _data[k].process;
+      if (_data[k].process != NULL) {
+        _data[k].process->blockSignals(true);
+        delete _data[k].process;
+      }
       _data[k].process = checkExecutableProcess(k);
       _data[k].command = _data[k].process->prettyCommand();
-      connect(_data[k].process, SIGNAL(done(int)), SLOT(checkExecutableDone()));
+      connect(_data[k].process, SIGNAL(done()), SLOT(checkExecutableDone()));
+      connect(_data[k].process, SIGNAL(error()), SLOT(checkExecutableDone()));
       connect(_data[k].process, SIGNAL(timeout()), SLOT(checkExecutableDone()));
       QString exec = baseExecutable(k);
-      if ( !_data[k].process->start(5000) ) _data[k].label->setText(i18n("\"%1\" not found").arg(exec));
-      else _data[k].label->setText(i18n("Detecting \"%1\"...").arg(exec));
+      _data[k].process->start(5000);
+      _data[k].label->setText(i18n("Detecting \"%1\"...").arg(exec));
     }
   }
 
@@ -234,12 +238,13 @@ void ToolchainConfigWidget::detect()
       delete _devicesData[i].process;
       _devicesData[i].process = checkDevicesProcess(i);
       _devicesData[i].command = _devicesData[i].process->prettyCommand();
-      connect(_devicesData[i].process, SIGNAL(done(int)), SLOT(checkDevicesDone()));
+      connect(_devicesData[i].process, SIGNAL(done()), SLOT(checkDevicesDone()));
+      connect(_devicesData[i].process, SIGNAL(error()), SLOT(checkDevicesDone()));
       connect(_devicesData[i].process, SIGNAL(timeout()), SLOT(checkDevicesDone()));
       _devicesData[i].done = false;
       _devicesData[i].checkLines.clear();
-      if ( !_devicesData[i].process->start(5000) ) _devicesLabel->setText(i18n("Failed"));
-      else _devicesLabel->setText(i18n("Detecting ..."));
+      _devicesData[i].process->start(5000);
+      _devicesLabel->setText(i18n("Detecting ..."));
     }
   }
 
