@@ -10,11 +10,11 @@
 
 #include "jalv2_compile.h"
 #include "jalv2_config.h"
+#include "jalv2_generator.h"
 #include "devices/base/device_group.h"
 #include "devices/pic/pic/pic_memory.h"
 #include "devices/list/device_list.h"
 #include "common/global/process.h"
-#include "tools/jal/jal_generator.h"
 
 //----------------------------------------------------------------------------
 bool JALV2::Base::checkExecutableResult(Tool::ExecutableType, QStringList &lines) const
@@ -64,5 +64,5 @@ Compile::Config *JALV2::Group::configFactory(::Project& project) const
 
 Tool::SourceGenerator *JALV2::Group::sourceGeneratorFactory() const
 {
-  return new JAL::SourceGenerator;
+  return new JALV2::SourceGenerator;
 }
