@@ -33,8 +33,8 @@ QStringList JALV2::CompileFile::genericArguments(const Compile::Config &config)
 
 void JALV2::CompileFile::logLine(::Process::OutputType, const QString &line)
 {
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):\\s*(warning)(.+)", 1, 2, 4, 3)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):\\s*(.+)", 1, 2, 3, Log::LineType::Error)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):\\s*(warning)(.+)", 1, 2, 4, 3, Log::LineType::Warning)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):\\s*(.+)", 1, 2, 3, -1, Log::LineType::Error)) ) return;
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
