@@ -17,6 +17,7 @@
 #include "compile_config.h"
 #include "libgui/main_global.h"
 #include "progs/base/prog_group.h"
+#include "tools/custom/custom_process.h"
 #include "tool_list.h"
 
 Compile::Manager::Manager(QObject *parent)
@@ -244,11 +245,7 @@ bool Compile::Manager::executeNext()
       processFailed();
       return false;
     }
-    if ( !_base->start() ) {
-      log(Log::LineType::Error, i18n("Failed to execute command: check toolchain configuration."), Log::Delayed);
-      processFailed();
-      return false;
-    }
+    _base->start();
   }
   return true;
 }
@@ -261,7 +258,7 @@ void Compile::Manager::processDone()
   }
   if ( Main::toolGroup().isCustom() ) _customCommandIndex++;
   else {
-    FileData::List list = _base->files(0).onlyExistingFiles();
+    FileData::List list = _base->files(NULL).onlyExistingFiles();
     for (FileData::List::const_iterator it = list.begin(); it != list.end(); ++it) emit updateFile(*it);
   }
   QTimer::singleShot(0, this, SLOT(execute()));
@@ -291,13 +288,14 @@ bool Compile::Manager::executeCustom()
   }
   QString command = commands[_customCommandIndex];
   _base.reset(new CustomProcess(command));
-  Compile::Data data(Tool::Category::Nb_Types, QValueList<Item>(), Main::deviceData().name(),
+  QValueList<Item> items;
+  const PURL::UrlList files = Main::project()->absoluteFiles();
+  for (PURL::UrlList::const_iterator it = files.begin(); it != files.end(); ++it) {
+    items += Item(*it, Item::NotGenerated);
+  }
+  Compile::Data data(Tool::Category::Nb_Types, items, Main::deviceData().name(),
                      *Main::project(), NormalLinking, Build);
   _base->init(data, this);
-  if ( !_base->start() ) {
-    log(Log::LineType::Error, i18n("Failed to execute custom command #%1.").arg(_customCommandIndex+1), Log::Delayed);
-    processFailed();
-    return false;
-  }
+  _base->start();
   return true;
 }
