@@ -203,31 +203,43 @@ void Compile::BaseProcess::init(const Data &data, Manager *manager)
   _manager = manager;
 }
 
-bool Compile::BaseProcess::start()
+void Compile::BaseProcess::start()
 {
   _stdout = QString::null;
   _stderr = QString::null;
   delete _process;
   _process = new ::Process::LineSignal;
-  connect(_process, SIGNAL(done(int)), SLOT(done(int)));
+  connect(_process, SIGNAL(done()), SLOT(done()));
+  connect(_process, SIGNAL(error()), SLOT(error()));
   connect(_process, SIGNAL(timeout()), SLOT(timeout()));
   connect(_process, SIGNAL(logLine(::Process::OutputType, const QString &)),
           SLOT(logLine(::Process::OutputType, const QString &)));
   _process->setWorkingDirectory(directory().path());
   setupProcess();
   _manager->log(Log::LineType::Command, _process->arguments().join(" "));
-  return _process->start();
+  _process->start();
 }
 
-void Compile::BaseProcess::done(int code)
+void Compile::BaseProcess::error()
 {
+  _manager->log(Log::LineType::Error, i18n("*** Error executing command ***"));
+  _manager->processFailed();
+}
+
+void Compile::BaseProcess::done()
+{
+  int code = _process->exitCode();
   if ( code!=0 ) {
     _manager->log(Log::LineType::Error, i18n("*** Exited with status: %1 ***").arg(code));
     _manager->processFailed();
-  } else if ( _manager->hasError() ) {
+    return;
+  }
+  if ( _manager->hasError() ) {
     _manager->log(Log::LineType::Error, i18n("*** Error ***"));
     _manager->processFailed();
-  } else _manager->processDone();
+    return;
+  }
+  _manager->processDone();
 }
 
 void Compile::BaseProcess::timeout()
@@ -247,13 +259,15 @@ PURL::Url Compile::BaseProcess::url(PURL::FileType type, uint i) const
     ASSERT( i<(uint)_data.items.count() );
     url = _data.items[i].url;
   }
-  if ( type==PURL::Nb_FileTypes ) return url;
-  return url.toFileType(type);
+  if (type!=PURL::Nb_FileTypes) url = url.toFileType(type);
+  return url;
 }
 
 Compile::FileData Compile::BaseProcess::fileData(PURL::FileType type, FileActions actions) const
 {
-  return FileData(url(type, nbFiles()-1), actions);
+  PURL::Url tmp = url(type, nbFiles()-1);
+  if (actions & Compile::Generated) tmp = PURL::Url(Main::project()->directory(), tmp.filename());
+  return FileData(tmp, actions);
 }
 
 QString Compile::BaseProcess::outputFilepath() const
@@ -286,7 +300,11 @@ Compile::FileData::List Compile::BaseProcess::files(bool *ok) const
         if ( type==PURL::Hex && _data.project==0 ) actions |= Show;
         list += fileData(type, actions);
       }
-    } else list += FileData(url().toExtension(files[i]), Compile::Generated);
+    } else {
+      PURL::Url url = _data.items[nbFiles()-1].url;
+      url = PURL::Url(Main::project()->directory(), url.filename()).toExtension(files[i]);
+      list += FileData(url, Compile::Generated);
+    }
   }
   return list;
 }
@@ -473,22 +491,3 @@ void Compile::Process::doLog(Log::LineType type, const QString &message, const Q
   }
   static_cast<LogWidget *>(_manager->view())->appendLine(type, s + message.stripWhiteSpace(), LogData(url, line));
 }
-
-//-----------------------------------------------------------------------------
-void Compile::CustomProcess::setupProcess()
-{
-  _process->setUseShell(true);
-  QStringList args = QStringList::split(" ", _command);
-  args = process(args);
-  _process->setup(args.join(" "), QStringList(), false);
-}
-
-void Compile::CustomProcess::logLine(::Process::OutputType, const QString &line)
-{
-  _manager->log(Log::LineType::Normal, line);
-}
-
-QString Compile::CustomProcess::deviceName() const
-{
-  return GPUtils::toDeviceName(_data.device);
-}
