@@ -28,11 +28,11 @@ void MPC::CompileFile::logLine(::Process::OutputType, const QString &)
 
 void MPC::CompileFile::parseLine(const QString &line)
 {
-  if ( parseErrorLine(line, Compile::ParseErrorData("(\\w+)\\s+(.*)\\s+(\\d+):\\d+:(.*)", 2, 3, 4, 1)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("(\\w+)\\s+(.*)\\s+(\\d+):\\d+:(.*)", 2, 3, 4, 1, Log::LineType::Error)) ) return;
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
-void MPC::CompileFile::done(int code)
+void MPC::CompileFile::done()
 {
   // rely on error file
   PURL::Url url = PURL::Url(directory(), inputFilepath(0)).toExtension("err");
@@ -43,7 +43,7 @@ void MPC::CompileFile::done(int code)
     QStringList lines = file.readLines();
     for (int i=0; i<lines.count(); i++) parseLine(lines[i]);
   }
-  Compile::Process::done(code);
+  Compile::Process::done();
 }
 
 QString MPC::CompileFile::outputFiles() const
