@@ -13,6 +13,8 @@
 #include "sdcc_config.h"
 #include "tools/list/tool_list.h"
 #include "sdcc_generator.h"
+#include "devices/list/device_list.h"
+#include "devices/pic/base/pic.h"
 
 //-----------------------------------------------------------------------------
 QString SDCC::Process::familyName() const
@@ -43,13 +45,13 @@ QString SDCC::Process::outputFiles() const
 
 void SDCC::Process::logLine(::Process::OutputType, const QString &line)
 {
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):( syntax error):(.+)", 1, 2, 4, -1)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):( error)(.+)", 1, 2, 4, -1)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(error|warning|message):(.+)", 1, 2, 4, 3)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(\\w+)\\s*\\[[0-9]+\\](.+)", 1, 2, 4, 3)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):( syntax error):(.+)", 1, 2, 4, -1, Log::LineType::Error)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):( error)(.+)", 1, 2, 4, -1, Log::LineType::Error)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(error|warning|message):(.+)", 1, 2, 4, 3, Log::LineType::Error)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(\\w+)\\s*\\[[0-9]+\\](.+)", 1, 2, 4, 3, Log::LineType::Error)) ) return;
   if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*)\\s*[0-9]+:(.+)", -1, -1, 2, 1, Log::LineType::Warning)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(.+)", 1, 2, 3, Log::LineType::Warning)) ) return;
-  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([^:]+):([0-9]+):(.+)", 2, 3, 4, Log::LineType::Warning)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([0-9]+):(.+)", 1, 2, 3, -1, Log::LineType::Warning)) ) return;
+  if ( parseErrorLine(line, Compile::ParseErrorData("([^:]*):([^:]+):([0-9]+):(.+)", 2, 3, 4, -1, Log::LineType::Warning)) ) return;
   if ( parseErrorLine(line, Compile::ParseErrorData("([^:]+):(.+)", -1, -1, 2, 1, Log::LineType::Warning)) ) return;
   doLog(filterType(line), line, QString::null, 0);
 }
@@ -72,6 +74,18 @@ QStringList SDCC::LinkProjectFile::genericArguments(const Compile::Config &confi
   args += "-Wl-c"; // create coff file
   args += "-Wl-m"; // output map file
   args += "$LKR(-Wl-s%LKR)";
+  if (family(_data.device) == P14) {
+    const Device::Data* data = Device::Lister::instance().data(_data.device);
+    if (static_cast<const Pic::Data&>(*data).architecture().type() == Pic::Architecture::EMidRange) {
+      args += "libme.lib";
+    } else {
+      args += "libm.lib";
+    }
+  } else {
+    args += "libio" + _data.device.toLower() + ".lib";
+    args += "libm18f.lib";
+    args += "libc18f.lib";
+  }
   args += config.includeDirs(Tool::Category::Linker, "-I");
   args += config.customOptions(Tool::Category::Linker);
   args += "-o%O";
