@@ -69,8 +69,8 @@ SourceLine::List SDCC::SourceGenerator::configLines(PURL::ToolType type, const D
     QStringList cnames = SourceLine::configNames(Pic::ConfigNameType::SDCC, pmemory, i, ok);
     if ( cnames.isEmpty() ) continue;
     QString code;
-    if ( data.is18Family() ) code += "code char at ";
-    else code += "word at ";
+    if ( data.is18Family() ) code += "__code char __at ";
+    else code += "word __at ";
     if ( cword.name.isEmpty() ) code += toHexLabel(address, data.nbCharsAddress()) + " CONFIG";
     else code += prefix + cword.name + " " + cword.name;
     code += " = " + cnames.join(" & ") + ";";
