@@ -26,6 +26,7 @@ public:
 
 protected:
   QString _basename, _namespace;
+  virtual QString namespaceName() const { return _namespace; }
   virtual bool hasFamilies() const { return true; }
   const QStringList &families() const { return _families; }
   virtual uint familyIndex(const QString &family) const { return _families.findIndex(family); }
@@ -79,7 +80,7 @@ void ExtXmlToData<Data>::parseDevice(QDomElement element)
   PData data;
   if (hasFamilies()) {
     QString family = element.attribute("family");
-    if (family.isEmpty()) qFatal(QString("Family is empty").arg(family));
+    if (family.isEmpty()) qFatal("Family is empty");
     if (_families.find(family) == _families.end()) _families.append(family);
     data.family = familyIndex(family);
   }
